@@ -1,8 +1,6 @@
 /*! \file create.cpp
  * \brief Commands that create new objects.
  *
- * $Id: create.cpp 4107 2009-01-18 17:24:43Z brazilofmux $
- *
  * This affects creation and destruction of all object types as well as their
  * initial and final relationships with other objects.
  */
@@ -61,7 +59,7 @@ static void open_exit(dbref player, dbref loc, UTF8 *direction, UTF8 *linkto)
     {
         return;
     }
-    if (  NULL == direction
+    if (  nullptr == direction
        || '\0' == direction[0])
     {
         notify_quiet(player, T("Open where?"));
@@ -89,14 +87,12 @@ static void open_exit(dbref player, dbref loc, UTF8 *direction, UTF8 *linkto)
     s_Next(exit, Exits(loc));
     s_Exits(loc, exit);
     local_data_create(exit);
-#if defined(TINYMUX_MODULES)
     ServerEventsSinkNode *p = g_pServerEventsSinkListHead;
-    while (NULL != p)
+    while (nullptr != p)
     {
         p->pSink->data_create(exit);
         p = p->pNext;
     }
-#endif // TINYMUX_MODULES
 
     // and we're done
     //
@@ -155,7 +151,7 @@ void do_open(dbref executor, dbref caller, dbref enactor, int eval, int key,
     }
     else
     {
-        dest = NULL;
+        dest = nullptr;
     }
 
     dbref loc;
@@ -277,7 +273,7 @@ void do_link
     //
     if (!where || !*where)
     {
-        do_unlink(executor, caller, enactor, 0, key, what, NULL, 0);
+        do_unlink(executor, caller, enactor, 0, key, what, nullptr, 0);
         return;
     }
 
@@ -533,14 +529,14 @@ void do_parent
             UTF8* action = atr_get("do_parent.529", previous_parent, A_APARENT,
                 &aowner, &aflags);
 
-            if (  NULL != action
+            if (  nullptr != action
                && '\0' != action[0])
             {
                 mux_sprintf(child, SBUF_SIZE, T("#%d"), thing);
                 mux_sprintf(original_executor, SBUF_SIZE, T("#%d"), executor);
                 xargs[1] = removal;
 
-                did_it(previous_parent, previous_parent, 0, NULL, 0, NULL,
+                did_it(previous_parent, previous_parent, 0, nullptr, 0, nullptr,
                         A_APARENT, 0, xargs, xnargs);
             }
             free_lbuf(action);
@@ -553,14 +549,14 @@ void do_parent
             UTF8* action = atr_get("do_parent.550", parent, A_APARENT,
                 &aowner, &aflags);
 
-            if (  NULL != action
+            if (  nullptr != action
                && '\0' != action[0])
             {
                 mux_sprintf(child, SBUF_SIZE, T("#%d"), thing);
                 mux_sprintf(original_executor, SBUF_SIZE, T("#%d"), executor);
                 xargs[1] = addition;
 
-                did_it(parent, parent, 0, NULL, 0, NULL, A_APARENT, 0,
+                did_it(parent, parent, 0, nullptr, 0, nullptr, A_APARENT, 0,
                     xargs, xnargs);
             }
             free_lbuf(action);
@@ -607,14 +603,12 @@ void do_dig(dbref executor, dbref caller, dbref enactor, int eval, int key,
 
     local_data_create(room);
 
-#if defined(TINYMUX_MODULES)
     ServerEventsSinkNode *p = g_pServerEventsSinkListHead;
-    while (NULL != p)
+    while (nullptr != p)
     {
         p->pSink->data_create(room);
         p = p->pNext;
     }
-#endif // TINYMUX_MODULES
 
     notify(executor, tprintf(T("%s created as room #%d."), name, room));
 
@@ -691,14 +685,12 @@ void do_create
 
     local_data_create(thing);
 
-#if defined(TINYMUX_MODULES)
     ServerEventsSinkNode *p = g_pServerEventsSinkListHead;
-    while (NULL != p)
+    while (nullptr != p)
     {
         p->pSink->data_create(thing);
         p = p->pNext;
     }
-#endif // TINYMUX_MODULES
 }
 
 
@@ -789,7 +781,7 @@ void do_clone
             cost = mudconf.createmin;
         if (cost > mudconf.createmax)
             cost = mudconf.createmax;
-        arg2 = NULL;
+        arg2 = nullptr;
     }
     else
     {
@@ -821,7 +813,7 @@ void do_clone
     //
     bool bValid = false;
     size_t nValidName;
-    UTF8 *pValidName = NULL;
+    UTF8 *pValidName = nullptr;
     switch (Typeof(thing))
     {
     case TYPE_THING:
@@ -873,7 +865,7 @@ void do_clone
 
     FLAGSET clearflags;
     TranslateFlags_Clone(clearflags.word, executor, key);
-    SetClearFlags(clone, clearflags.word, NULL);
+    SetClearFlags(clone, clearflags.word, nullptr);
 
     // Tell creator about it
     //
@@ -933,7 +925,7 @@ void do_clone
         {
             s_Parent(clone, Parent(thing));
         }
-        did_it(executor, clone, 0, NULL, 0, NULL, A_ACLONE, 0, NULL, 0);
+        did_it(executor, clone, 0, nullptr, 0, nullptr, A_ACLONE, 0, nullptr, 0);
     }
     else
     {
@@ -947,14 +939,12 @@ void do_clone
 
     local_data_clone(clone, thing);
 
-#if defined(TINYMUX_MODULES)
     ServerEventsSinkNode *p = g_pServerEventsSinkListHead;
-    while (NULL != p)
+    while (nullptr != p)
     {
         p->pSink->data_clone(clone, thing);
         p = p->pNext;
     }
-#endif // TINYMUX_MODULES
 }
 
 // ---------------------------------------------------------------------------
