@@ -1,8 +1,6 @@
 /*! \file externs.h
  * \brief Prototypes for externs not defined elsewhere.
  *
- * $Id: externs.h 5585 2012-05-07 16:59:46Z brazilofmux $
- *
  */
 
 #ifndef EXTERNS_H
@@ -10,10 +8,37 @@
 
 #include "db.h"
 #include "match.h"
-#if defined(TINYMUX_MODULES)
 #include "libmux.h"
 #include "modules.h"
-#endif
+
+class CResultsSet
+{
+public:
+    CResultsSet(QUEUE_INFO *pqi);
+    ~CResultsSet(void);
+    UINT32 Release(void);
+    UINT32 AddRef(void);
+    bool   isLoaded(void);
+    void   SetError(UINT32 iError);
+    UINT32 GetError(void);
+    int    GetRowCount(void);
+    const UTF8 *FirstField(int iRow);
+    const UTF8 *NextField(void);
+
+private:
+    UINT32 m_cRef;
+    int    m_nFields;
+    size_t m_nBlob;
+    UTF8  *m_pBlob;
+    bool   m_bLoaded;
+    UINT32 m_iError;
+    int    m_nRows;
+    PUTF8 *m_pRows;
+
+    const UTF8 *m_pCurrentField;
+    int         m_iCurrentField;
+};
+
 #include "mudconf.h"
 #include "svdrand.h"
 
@@ -24,7 +49,7 @@ int  cf_modify_bits(int *, UTF8 *, void *, UINT32, dbref, UTF8 *);
 void DCL_CDECL cf_log_syntax(dbref player, __in_z UTF8 *cmd, __in_z const UTF8 *fmt, ...);
 void ValidateConfigurationDbrefs(void);
 #if defined(HAVE_IN_ADDR)
-bool MakeCanonicalIPv4(const UTF8 *str, in_addr_t *pnIP);
+bool make_canonical_IPv4(const UTF8 *str, in_addr_t *pnIP);
 #endif
 int  cf_read(void);
 void cf_init(void);
@@ -117,7 +142,7 @@ void mux_exec(const UTF8 *pdstr, size_t nStr, UTF8 *buff, UTF8 **bufc, dbref exe
 
 inline void BufAddRef(lbuf_ref *lbufref)
 {
-    if (NULL != lbufref)
+    if (nullptr != lbufref)
     {
         lbufref->refcount++;
     }
@@ -125,13 +150,13 @@ inline void BufAddRef(lbuf_ref *lbufref)
 
 inline void BufRelease(lbuf_ref *lbufref)
 {
-    if (NULL != lbufref)
+    if (nullptr != lbufref)
     {
         lbufref->refcount--;
         if (0 == lbufref->refcount)
         {
             free_lbuf(lbufref->lbuf_ptr);
-            lbufref->lbuf_ptr = NULL;
+            lbufref->lbuf_ptr = nullptr;
             free_lbufref(lbufref);
         }
     }
@@ -139,7 +164,7 @@ inline void BufRelease(lbuf_ref *lbufref)
 
 inline void RegAddRef(reg_ref *regref)
 {
-    if (NULL != regref)
+    if (nullptr != regref)
     {
         regref->refcount++;
     }
@@ -147,14 +172,14 @@ inline void RegAddRef(reg_ref *regref)
 
 inline void RegRelease(reg_ref *regref)
 {
-    if (NULL != regref)
+    if (nullptr != regref)
     {
         regref->refcount--;
         if (0 == regref->refcount)
         {
             BufRelease(regref->lbuf);
-            regref->lbuf    = NULL;
-            regref->reg_ptr = NULL;
+            regref->lbuf    = nullptr;
+            regref->reg_ptr = nullptr;
             regref->reg_len = 0;
             free_regref(regref);
         }
@@ -535,6 +560,8 @@ extern int anum_alc_top;
 #define ATTRIB_INFO     8   /* Info (number, flags) about attribute */
 #define BOOT_QUIET      1   /* Inhibit boot message to victim */
 #define BOOT_PORT       2   /* Boot by port number */
+#define BREAK_INLINE    1   // Evaluate @break action inline
+#define BREAK_QUEUED    2   // Queue @break action.
 #define CEMIT_NOHEADER  1   /* Channel emit without header */
 #define CHOWN_ONE       1   /* item = new_owner */
 #define CHOWN_ALL       2   /* old_owner = new_owner */
@@ -804,9 +831,13 @@ extern int anum_alc_top;
 
 /* Character Set Restrictions */
 
-#define ALLOW_CHARSET_ASCII  1
-#define ALLOW_CHARSET_8859_1 2
-#define ALLOW_CHARSET_8859_2 4
+#define ALLOW_CHARSET_ASCII       0x00000001UL
+#define ALLOW_CHARSET_HANGUL      0x00000002UL
+#define ALLOW_CHARSET_HIRAGANA    0x00000004UL
+#define ALLOW_CHARSET_KANJI       0x00000008UL
+#define ALLOW_CHARSET_KATAKANA    0x00000010UL
+#define ALLOW_CHARSET_8859_1      0x00000020UL
+#define ALLOW_CHARSET_8859_2      0x00000040UL
 
 /* Password Encryption Methods */
 
@@ -1010,6 +1041,7 @@ void dispatch_DatabaseDump(void *pUnused, int iUnused);
 void dispatch_FreeListReconstruction(void *pUnused, int iUnused);
 void dispatch_IdleCheck(void *pUnused, int iUnused);
 void dispatch_CheckEvents(void *pUnused, int iUnused);
+void dispatch_KeepAlive(void *pUnused, int iUnused);
 #ifndef MEMORY_BASED
 void dispatch_CacheTick(void *pUnused, int iUnused);
 #endif
@@ -1187,4 +1219,17 @@ void stack_clr(dbref obj);
 #endif // DEPRECATED
 bool parse_and_get_attrib(dbref, UTF8 *[], UTF8 **, dbref *, dbref *, int *, UTF8 *, UTF8 **);
 
+DEFINE_FACTORY(CLogFactory)
+
+typedef struct ServerEventsSinkNode
+{
+    mux_IServerEventsSink        *pSink;
+    struct ServerEventsSinkNode  *pNext;
+} ServerEventsSinkNode;
+extern ServerEventsSinkNode *g_pServerEventsSinkListHead;
+
+DEFINE_FACTORY(CServerEventsSourceFactory)
+DEFINE_FACTORY(CQueryClientFactory)
+DEFINE_FACTORY(CFunctionsFactory)
+
 #endif // EXTERNS_H
