@@ -1,8 +1,6 @@
 /*! \file funceval2.cpp
  * \brief MUX function handlers.
  *
- * $Id: funceval2.cpp 5908 2017-01-31 15:40:51Z sdennis $
- *
  * This file began as a place to put function handlers ported from other
  * MU* servers, but has also become home to miscellaneous new functions.
  * These handlers include side-effect functions, comsys / mail functions,
@@ -103,7 +101,7 @@ FUNCTION(fun_scramble)
     UNUSED_PARAMETER(cargs);
     UNUSED_PARAMETER(ncargs);
 
-    mux_string *sStr = NULL;
+    mux_string *sStr = nullptr;
     try
     {
         sStr = new mux_string(fargs[0]);
@@ -113,7 +111,7 @@ FUNCTION(fun_scramble)
         ; // Nothing.
     }
 
-    if (NULL == sStr)
+    if (nullptr == sStr)
     {
         return;
     }
@@ -122,7 +120,7 @@ FUNCTION(fun_scramble)
 
     if (2 <= nPoints)
     {
-        mux_string *sOut = NULL;
+        mux_string *sOut = nullptr;
         try
         {
             sOut = new mux_string;
@@ -132,7 +130,7 @@ FUNCTION(fun_scramble)
             ; // Nothing.
         }
 
-        if (NULL == sOut)
+        if (nullptr == sOut)
         {
             delete sStr;
             return;
@@ -178,7 +176,7 @@ FUNCTION(fun_shuffle)
         return;
     }
 
-    mux_string *sIn = NULL;
+    mux_string *sIn = nullptr;
     try
     {
         sIn = new mux_string(fargs[0]);
@@ -188,12 +186,12 @@ FUNCTION(fun_shuffle)
         ; // Nothing.
     }
 
-    if (NULL == sIn)
+    if (nullptr == sIn)
     {
         return;
     }
 
-    mux_words *words = NULL;
+    mux_words *words = nullptr;
     try
     {
         words = new mux_words(*sIn);
@@ -203,14 +201,14 @@ FUNCTION(fun_shuffle)
         ; // Nothing.
     }
 
-    if (NULL == words)
+    if (nullptr == words)
     {
         delete sIn;
         return;
     }
 
     LBUF_OFFSET n = words->find_Words(sep.str);
-    mux_string *sOut = NULL;
+    mux_string *sOut = nullptr;
     try
     {
         sOut = new mux_string;
@@ -220,7 +218,7 @@ FUNCTION(fun_shuffle)
         ; // Nothing.
     }
 
-    if (NULL == sOut)
+    if (nullptr == sOut)
     {
         delete sIn;
         delete words;
@@ -274,8 +272,8 @@ FUNCTION(fun_pickrand)
         return;
     }
 
-    mux_string *sStr = NULL;
-    mux_words *words = NULL;
+    mux_string *sStr = nullptr;
+    mux_words *words = nullptr;
     try
     {
         sStr = new mux_string(s);
@@ -286,8 +284,8 @@ FUNCTION(fun_pickrand)
         ; // Nothing.
     }
 
-    if (  NULL != sStr
-       && NULL != words)
+    if (  nullptr != sStr
+       && nullptr != words)
     {
         INT32 n = static_cast<INT32>(words->find_Words(sep.str));
 
@@ -316,7 +314,7 @@ static int u_comp(ucomp_context *pctx, const void *s1, const void *s2)
 {
     if (  mudstate.func_invk_ctr > mudconf.func_invk_lim
        || mudstate.func_nest_lev > mudconf.func_nest_lim
-       || MuxAlarm.bAlarmed)
+       || alarm_clock.alarmed)
     {
         return 0;
     }
@@ -443,8 +441,8 @@ FUNCTION(fun_last)
         return;
     }
 
-    mux_string *sStr = NULL;
-    mux_words *words = NULL;
+    mux_string *sStr = nullptr;
+    mux_words *words = nullptr;
     try
     {
         sStr = new mux_string(fargs[0]);
@@ -455,8 +453,8 @@ FUNCTION(fun_last)
         ; // Nothing.
     }
 
-    if (  NULL != sStr
-       && NULL != words)
+    if (  nullptr != sStr
+       && nullptr != words)
     {
         LBUF_OFFSET nWords = words->find_Words(sep.str);
         words->export_WordColor(nWords-1, buff, bufc);
@@ -537,7 +535,7 @@ FUNCTION(fun_lastcreate)
     UTF8* newobject_string = atr_get("fun_lastcreate.2998", target,
             A_NEWOBJS, &aowner, &aflags);
 
-    if (  NULL == newobject_string
+    if (  nullptr == newobject_string
        || '\0' == newobject_string[0])
     {
         safe_str(T("#-1"), buff, bufc);
@@ -551,7 +549,7 @@ FUNCTION(fun_lastcreate)
     int i;
     UTF8* ptr;
     for ( ptr = mux_strtok_parse(&tts), i = 0;
-          NULL != ptr && i < 5;
+          nullptr != ptr && i < 5;
           ptr = mux_strtok_parse(&tts), i++)
     {
         if (i == iObjectPosition)
@@ -700,7 +698,7 @@ FUNCTION(fun_mix)
     for (  int wc = 0;
            wc < nwords
         && mudstate.func_invk_ctr < mudconf.func_invk_lim
-        && !MuxAlarm.bAlarmed;
+        && !alarm_clock.alarmed;
            wc++)
     {
         if (!bFirst)
@@ -715,7 +713,7 @@ FUNCTION(fun_mix)
         for (i = 0; i < lastn; i++)
         {
             os[i] = split_token(&cp[i], sep);
-            if (NULL == os[i])
+            if (nullptr == os[i])
             {
                 os[i] = T("");
             }
@@ -774,7 +772,7 @@ FUNCTION(fun_step)
     bool bFirst = true;
     while (  cp
           && mudstate.func_invk_ctr < mudconf.func_invk_lim
-          && !MuxAlarm.bAlarmed)
+          && !alarm_clock.alarmed)
     {
         if (!bFirst)
         {
@@ -827,7 +825,7 @@ FUNCTION(fun_foreach)
 
     UTF8 cbuf[5] = {'\0', '\0', '\0', '\0', '\0'};
     const UTF8 *bp = cbuf;
-    mux_string *sStr = NULL;
+    mux_string *sStr = nullptr;
     try
     {
         sStr = new mux_string(fargs[1]);
@@ -837,7 +835,7 @@ FUNCTION(fun_foreach)
         ; // Nothing.
     }
 
-    if (NULL == sStr)
+    if (nullptr == sStr)
     {
         return;
     }
@@ -855,7 +853,7 @@ FUNCTION(fun_foreach)
 
         while (  i < nStr
               && mudstate.func_invk_ctr < mudconf.func_invk_lim
-              && !MuxAlarm.bAlarmed)
+              && !alarm_clock.alarmed)
         {
             nBytes = sStr->export_Char_UTF8(i, cbuf);
             i = i + nBytes;
@@ -895,7 +893,7 @@ FUNCTION(fun_foreach)
     {
         while (  i < nStr
               && mudstate.func_invk_ctr < mudconf.func_invk_lim
-              && !MuxAlarm.bAlarmed)
+              && !alarm_clock.alarmed)
         {
             nBytes = sStr->export_Char_UTF8(i, cbuf);
 
@@ -965,8 +963,8 @@ FUNCTION(fun_munge)
         return;
     }
 
-    munge_htab_rec *htab = NULL;
-    UINT16 *tails = NULL;
+    munge_htab_rec *htab = nullptr;
+    UINT16 *tails = nullptr;
     try
     {
         htab = new munge_htab_rec[1 + 2 * nWords];
@@ -977,16 +975,16 @@ FUNCTION(fun_munge)
         ; // Nothing.
     }
 
-    if (  NULL == htab
-       || NULL == tails)
+    if (  nullptr == htab
+       || nullptr == tails)
     {
         free_lbuf(atext);
         free_lbuf(list1);
-        if (NULL != htab)
+        if (nullptr != htab)
         {
             delete [] htab;
         }
-        else if (NULL != tails)
+        else if (nullptr != tails)
         {
             delete [] tails;
         }
@@ -1004,7 +1002,7 @@ FUNCTION(fun_munge)
     UTF8 *p2 = trim_space_sep(fargs[2], sep);
     UTF8 *pKey, *pValue;
     for (pKey = split_token(&p1, sep), pValue = split_token(&p2, sep);
-         NULL != pKey && NULL != pValue;
+         nullptr != pKey && nullptr != pValue;
          pKey = split_token(&p1, sep), pValue = split_token(&p2, sep))
     {
         UINT32 nHash = munge_hash(pKey);
@@ -1029,8 +1027,8 @@ FUNCTION(fun_munge)
     }
     delete [] tails;
 
-    if (  NULL != pKey
-       || NULL != pValue)
+    if (  nullptr != pKey
+       || nullptr != pValue)
     {
         safe_str(T("#-1 LISTS MUST BE OF EQUAL SIZE"), buff, bufc);
         free_lbuf(atext);
@@ -1062,7 +1060,7 @@ FUNCTION(fun_munge)
     {
         UTF8 *result;
         for (result = split_token(&bp, sep);
-             NULL != result;
+             nullptr != result;
              result = split_token(&bp, sep))
         {
             UINT32 nHash = munge_hash(result);
@@ -1438,7 +1436,7 @@ FUNCTION(fun_unpack)
     int iRadix = 64;
     if (2 <= nfargs)
     {
-        if (  !is_integer(fargs[1], NULL)
+        if (  !is_integer(fargs[1], nullptr)
            || (iRadix = mux_atol(fargs[1])) < 2
            || 64 < iRadix)
         {
@@ -1475,8 +1473,8 @@ FUNCTION(fun_pack)
 
     // Validate the arguments are numeric.
     //
-    if (  !is_integer(fargs[0], NULL)
-       || (2 <= nfargs && !is_integer(fargs[1], NULL)))
+    if (  !is_integer(fargs[0], nullptr)
+       || (2 <= nfargs && !is_integer(fargs[1], nullptr)))
     {
         safe_str(T("#-1 ARGUMENTS MUST BE NUMBERS"), buff, bufc);
         return;
@@ -1517,8 +1515,8 @@ FUNCTION(fun_baseconv)
 
     // Validate that input and output radix are integers.
     //
-    if (  !is_integer(fargs[1], NULL)
-       || !is_integer(fargs[2], NULL))
+    if (  !is_integer(fargs[1], nullptr)
+       || !is_integer(fargs[2], nullptr))
     {
         safe_str(T("#-1 ARGUMENTS MUST BE NUMBERS"), buff, bufc);
         return;
@@ -1590,7 +1588,7 @@ static UTF8 *grep_util(dbref player, dbref thing, const UTF8 *pattern, const UTF
 
     dbref aowner;
     int aflags;
-    for (int ca = olist_first(); ca != NOTHING && !MuxAlarm.bAlarmed; ca = olist_next())
+    for (int ca = olist_first(); ca != NOTHING && !alarm_clock.alarmed; ca = olist_next())
     {
         size_t nText;
         UTF8 *attrib = atr_get_LEN(thing, ca, &aowner, &aflags, &nText);
@@ -1907,7 +1905,7 @@ static int stacksize(dbref doer)
 {
     int i;
     MUX_STACK *sp;
-    for (i = 0, sp = Stack(doer); sp != NULL; sp = sp->next, i++)
+    for (i = 0, sp = Stack(doer); sp != nullptr; sp = sp->next, i++)
     {
         // Nothing
         ;
@@ -1944,10 +1942,10 @@ FUNCTION(fun_lstack)
         safe_noperm(buff, bufc);
         return;
     }
-    for (sp = Stack(doer); sp != NULL; sp = sp->next)
+    for (sp = Stack(doer); sp != nullptr; sp = sp->next)
     {
         safe_str(sp->data, buff, bufc);
-        if (sp->next != NULL)
+        if (sp->next != nullptr)
         {
             safe_chr(' ', buff, bufc);
         }
@@ -1961,14 +1959,14 @@ void stack_clr(dbref obj)
     // Clear the stack.
     //
     MUX_STACK *sp, *next;
-    for (sp = Stack(obj); sp != NULL; sp = next)
+    for (sp = Stack(obj); sp != nullptr; sp = next)
     {
         next = sp->next;
         free_lbuf(sp->data);
         MEMFREE(sp);
-        sp = NULL;
+        sp = nullptr;
     }
-    s_Stack(obj, NULL);
+    s_Stack(obj, nullptr);
 }
 
 FUNCTION(fun_empty)
@@ -2085,7 +2083,7 @@ FUNCTION(fun_peek)
     sp = Stack(doer);
     while (count != pos)
     {
-        if (sp == NULL)
+        if (sp == nullptr)
         {
             return;
         }
@@ -2144,11 +2142,11 @@ FUNCTION(fun_pop)
     }
 
     MUX_STACK *sp = Stack(doer);
-    MUX_STACK *prev = NULL;
+    MUX_STACK *prev = nullptr;
     int count = 0;
     while (count != pos)
     {
-        if (sp == NULL)
+        if (sp == nullptr)
         {
             return;
         }
@@ -2163,14 +2161,14 @@ FUNCTION(fun_pop)
         s_Stack(doer, sp->next);
         free_lbuf(sp->data);
         MEMFREE(sp);
-        sp = NULL;
+        sp = nullptr;
     }
     else
     {
         prev->next = sp->next;
         free_lbuf(sp->data);
         MEMFREE(sp);
-        sp = NULL;
+        sp = nullptr;
     }
 }
 
@@ -2236,7 +2234,7 @@ FUNCTION(fun_push)
 static void real_regmatch(const UTF8 *search, const UTF8 *pattern, UTF8 *registers,
                    int nfargs, UTF8 *buff, UTF8 **bufc, bool cis)
 {
-    if (MuxAlarm.bAlarmed)
+    if (alarm_clock.alarmed)
     {
         return;
     }
@@ -2250,7 +2248,7 @@ static void real_regmatch(const UTF8 *search, const UTF8 *pattern, UTF8 *registe
     int ovec[ovecsize];
 
     pcre *re = pcre_compile((char *)pattern, PCRE_UTF8|(cis ? PCRE_CASELESS : 0),
-        &errptr, &erroffset, NULL);
+        &errptr, &erroffset, nullptr);
     if (!re)
     {
         // Matching error.
@@ -2260,7 +2258,7 @@ static void real_regmatch(const UTF8 *search, const UTF8 *pattern, UTF8 *registe
         return;
     }
 
-    int matches = pcre_exec(re, NULL, (char *)search, static_cast<int>(strlen((char *)search)), 0, 0,
+    int matches = pcre_exec(re, nullptr, (char *)search, static_cast<int>(strlen((char *)search)), 0, 0,
         ovec, ovecsize);
     if (matches == 0)
     {
@@ -2351,12 +2349,12 @@ FUNCTION(fun_regmatchi)
 static void real_regrab(__in UTF8 *search, __in const UTF8 *pattern, __in const SEP &sep, __in UTF8 *buff,
                  __deref_inout UTF8 **bufc, bool cis, bool all)
 {
-    if (MuxAlarm.bAlarmed)
+    if (alarm_clock.alarmed)
     {
         return;
     }
     pcre *re;
-    pcre_extra *study = NULL;
+    pcre_extra *study = nullptr;
     const char *errptr;
     int erroffset;
     // To capture N substrings, you need space for 3(N+1) offsets in the
@@ -2366,7 +2364,7 @@ static void real_regrab(__in UTF8 *search, __in const UTF8 *pattern, __in const
     int ovec[ovecsize];
 
     re = pcre_compile((char *)pattern, PCRE_UTF8|(cis ? PCRE_CASELESS : 0),
-        &errptr, &erroffset, NULL);
+        &errptr, &erroffset, nullptr);
     if (!re)
     {
         // Matching error.
@@ -2386,7 +2384,7 @@ static void real_regrab(__in UTF8 *search, __in const UTF8 *pattern, __in const
     do
     {
         UTF8 *r = split_token(&s, sep);
-        if (  !MuxAlarm.bAlarmed
+        if (  !alarm_clock.alarmed
            && pcre_exec(re, study, (char *)r, static_cast<int>(strlen((char *)r)), 0, 0, ovec, ovecsize) >= 0)
         {
             if (first)
@@ -2481,8 +2479,8 @@ CBitField::CBitField(unsigned int nMaximum_arg)
 {
     nMaximum = 0;
     nInts    = 0;
-    pInts    = NULL;
-    pMasks   = NULL;
+    pInts    = nullptr;
+    pMasks   = nullptr;
 
     nBitsPer = sizeof(UINT32)*8;
 
@@ -2574,11 +2572,11 @@ void CBitField::Resize(unsigned int nMaximum_arg)
 
 CBitField::~CBitField(void)
 {
-    pInts  = NULL;
+    pInts  = nullptr;
     if (pMasks)
     {
         MEMFREE(pMasks);
-        pMasks = NULL;
+        pMasks = nullptr;
     }
 }
 
