@@ -1,8 +1,6 @@
 /*! \file log.cpp
  * \brief Logging routines.
  *
- * $Id: log.cpp 4459 2009-12-05 16:53:59Z brazilofmux $
- *
  */
 
 #include "copyright.h"
@@ -19,7 +17,7 @@ NAMETAB logdata_nametab[] =
     {T("location"),        1,  0,  LOGOPT_LOC},
     {T("owner"),           1,  0,  LOGOPT_OWNER},
     {T("timestamp"),       1,  0,  LOGOPT_TIMESTAMP},
-    {(UTF8 *) NULL,        0,  0,  0}
+    {(UTF8 *) nullptr,     0,  0,  0}
 };
 
 NAMETAB logoptions_nametab[] =
@@ -42,7 +40,7 @@ NAMETAB logoptions_nametab[] =
     {T("suspect"),         2,  0,  LOG_SUSPECTCMDS},
     {T("time_usage"),      1,  0,  LOG_TIMEUSE},
     {T("wizard"),          1,  0,  LOG_WIZARD},
-    {(UTF8 *) NULL,        0,  0,  0}
+    {(UTF8 *) nullptr,     0,  0,  0}
 };
 
 /* ---------------------------------------------------------------------------
@@ -315,7 +313,7 @@ void do_log
         }
     }
 
-    UTF8 *pFullName = NULL;
+    UTF8 *pFullName = nullptr;
     const UTF8 *pMessage = T("");
     if (bValid)
     {
@@ -461,14 +459,14 @@ bool CLogFile::CreateLogFile(void)
 #if defined(WINDOWS_FILES)
     size_t nFilename;
     UTF16 *pFilename = ConvertFromUTF8ToUTF16(m_szFilename, &nFilename);
-    if (NULL == pFilename)
+    if (nullptr == pFilename)
     {
         return false;
     }
 
     m_hFile = CreateFile(pFilename, GENERIC_READ | GENERIC_WRITE,
         FILE_SHARE_READ, 0, CREATE_ALWAYS,
-        FILE_ATTRIBUTE_NORMAL + FILE_FLAG_SEQUENTIAL_SCAN, NULL);
+        FILE_ATTRIBUTE_NORMAL + FILE_FLAG_SEQUENTIAL_SCAN, nullptr);
     bSuccess = (INVALID_HANDLE_VALUE != m_hFile);
 #elif defined(UNIX_FILES)
     bSuccess = mux_open(&m_fdFile, m_szFilename,
@@ -485,14 +483,14 @@ void CLogFile::AppendLogFile(void)
 #if defined(WINDOWS_FILES)
     size_t nFilename;
     UTF16 *pFilename = ConvertFromUTF8ToUTF16(m_szFilename, &nFilename);
-    if (NULL == pFilename)
+    if (nullptr == pFilename)
     {
         return;
     }
 
     m_hFile = CreateFile(pFilename, GENERIC_READ | GENERIC_WRITE,
         FILE_SHARE_READ, 0, OPEN_ALWAYS,
-        FILE_ATTRIBUTE_NORMAL + FILE_FLAG_SEQUENTIAL_SCAN, NULL);
+        FILE_ATTRIBUTE_NORMAL + FILE_FLAG_SEQUENTIAL_SCAN, nullptr);
     bSuccess = (INVALID_HANDLE_VALUE != m_hFile);
 #elif defined(UNIX_FILES)
     bSuccess = mux_open(&m_fdFile, m_szFilename, O_RDWR | O_BINARY);
@@ -547,7 +545,7 @@ void CLogFile::Flush(void)
 #if defined(WINDOWS_FILES)
         unsigned long nWritten;
         bool fSuccess = true;
-        if (!WriteFile(m_hFile, m_aBuffer, (DWORD) m_nBuffer, &nWritten, NULL))
+        if (!WriteFile(m_hFile, m_aBuffer, (DWORD) m_nBuffer, &nWritten, nullptr))
         {
             fSuccess = false;
         }
@@ -608,7 +606,7 @@ void CLogFile::SetBasename(const UTF8 * pBasename)
     if (m_pBasename)
     {
         MEMFREE(m_pBasename);
-        m_pBasename = NULL;
+        m_pBasename = nullptr;
     }
 
     if (  pBasename
@@ -646,7 +644,7 @@ CLogFile::CLogFile(void)
     m_nBuffer = 0;
     bEnabled = false;
     bUseStderr = true;
-    m_pBasename = NULL;
+    m_pBasename = nullptr;
     m_szPrefix[0] = '\0';
     m_szFilename[0] = '\0';
 }
@@ -672,7 +670,7 @@ void CLogFile::StopLogging(void)
         CloseLogFile();
         m_szPrefix[0] = '\0';
         m_szFilename[0] = '\0';
-        SetBasename(NULL);
+        SetBasename(nullptr);
     }
 }
 
@@ -683,3 +681,213 @@ CLogFile::~CLogFile(void)
     DeleteCriticalSection(&csLog);
 #endif // WINDOWS_THREADS
 }
+
+// CLog component which is not directly accessible.
+//
+class CLog : public mux_ILog
+{
+public:
+    // mux_IUnknown
+    //
+    virtual MUX_RESULT QueryInterface(MUX_IID iid, void **ppv);
+    virtual UINT32     AddRef(void);
+    virtual UINT32     Release(void);
+
+    // mux_ILog
+    //
+    virtual MUX_RESULT start_log(bool *pStarted, int key, const UTF8 *primary, const UTF8 *secondary);
+    virtual MUX_RESULT log_perror(const UTF8 *primary, const UTF8 *secondary, const UTF8 *extra, const UTF8 *failing_object);
+    virtual MUX_RESULT log_text(const UTF8 *text);
+    virtual MUX_RESULT log_number(int num);
+    virtual MUX_RESULT log_name(dbref target);
+    virtual MUX_RESULT log_name_and_loc(dbref player);
+    virtual MUX_RESULT log_type_and_name(dbref thing);
+    virtual MUX_RESULT end_log(void);
+
+    CLog(void);
+    virtual ~CLog();
+
+private:
+    UINT32 m_cRef;
+};
+
+CLog::CLog(void) : m_cRef(1)
+{
+}
+
+CLog::~CLog()
+{
+}
+
+MUX_RESULT CLog::QueryInterface(MUX_IID iid, void **ppv)
+{
+    if (mux_IID_IUnknown == iid)
+    {
+        *ppv = static_cast<mux_ILog *>(this);
+    }
+    else if (IID_ILog == iid)
+    {
+        *ppv = static_cast<mux_ILog *>(this);
+    }
+    else
+    {
+        *ppv = nullptr;
+        return MUX_E_NOINTERFACE;
+    }
+    reinterpret_cast<mux_IUnknown *>(*ppv)->AddRef();
+    return MUX_S_OK;
+}
+
+UINT32 CLog::AddRef(void)
+{
+    m_cRef++;
+    return m_cRef;
+}
+
+UINT32 CLog::Release(void)
+{
+    m_cRef--;
+    if (0 == m_cRef)
+    {
+        delete this;
+        return 0;
+    }
+    return m_cRef;
+}
+
+MUX_RESULT CLog::start_log(bool *fStarted, int key, const UTF8 *primary, const UTF8 *secondary)
+{
+    if (  ((key) & mudconf.log_options) != 0
+       && ::start_log(primary, secondary))
+    {
+        *fStarted = true;
+    }
+    else
+    {
+        *fStarted = false;
+    }
+    return MUX_S_OK;
+}
+
+MUX_RESULT CLog::log_perror(const UTF8 *primary, const UTF8 *secondary, const UTF8 *extra, const UTF8 *failing_object)
+{
+    ::log_perror(primary, secondary, extra, failing_object);
+    return MUX_S_OK;
+}
+
+MUX_RESULT CLog::log_text(const UTF8 *text)
+{
+    ::log_text(text);
+    return MUX_S_OK;
+}
+
+MUX_RESULT CLog::log_number(int num)
+{
+    ::log_number(num);
+    return MUX_S_OK;
+}
+
+MUX_RESULT CLog::log_name(dbref target)
+{
+    ::log_name(target);
+    return MUX_S_OK;
+}
+
+MUX_RESULT CLog::log_name_and_loc(dbref player)
+{
+    ::log_name_and_loc(player);
+    return MUX_S_OK;
+}
+
+MUX_RESULT CLog::log_type_and_name(dbref thing)
+{
+    ::log_type_and_name(thing);
+    return MUX_S_OK;
+}
+
+MUX_RESULT CLog::end_log(void)
+{
+    ::end_log();
+    return MUX_S_OK;
+}
+
+// Factory for CLog component which is not directly accessible.
+//
+CLogFactory::CLogFactory(void) : m_cRef(1)
+{
+}
+
+CLogFactory::~CLogFactory()
+{
+}
+
+MUX_RESULT CLogFactory::QueryInterface(MUX_IID iid, void **ppv)
+{
+    if (mux_IID_IUnknown == iid)
+    {
+        *ppv = static_cast<mux_IClassFactory *>(this);
+    }
+    else if (mux_IID_IClassFactory == iid)
+    {
+        *ppv = static_cast<mux_IClassFactory *>(this);
+    }
+    else
+    {
+        *ppv = nullptr;
+        return MUX_E_NOINTERFACE;
+    }
+    reinterpret_cast<mux_IUnknown *>(*ppv)->AddRef();
+    return MUX_S_OK;
+}
+
+UINT32 CLogFactory::AddRef(void)
+{
+    m_cRef++;
+    return m_cRef;
+}
+
+UINT32 CLogFactory::Release(void)
+{
+    m_cRef--;
+    if (0 == m_cRef)
+    {
+        delete this;
+        return 0;
+    }
+    return m_cRef;
+}
+
+MUX_RESULT CLogFactory::CreateInstance(mux_IUnknown *pUnknownOuter, MUX_IID iid, void **ppv)
+{
+    // Disallow attempts to aggregate this component.
+    //
+    if (nullptr != pUnknownOuter)
+    {
+        return MUX_E_NOAGGREGATION;
+    }
+
+    CLog *pLog = nullptr;
+    try
+    {
+        pLog = new CLog;
+    }
+    catch (...)
+    {
+        ; // Nothing.
+    }
+
+    if (nullptr == pLog)
+    {
+        return MUX_E_OUTOFMEMORY;
+    }
+
+    MUX_RESULT mr = pLog->QueryInterface(iid, ppv);
+    pLog->Release();
+    return mr;
+}
+
+MUX_RESULT CLogFactory::LockServer(bool bLock)
+{
+    UNUSED_PARAMETER(bLock);
+    return MUX_S_OK;
+}
