@@ -4,8 +4,6 @@
  * Interfaces and classes declared here are built into the netmux server and
  * are available to netmux itself and to dynamically-loaded external modules.
  *
- * $Id: modules.cpp 5497 2012-03-10 17:11:05Z brazilofmux $
- *
  */
 
 #include "copyright.h"
@@ -14,16 +12,17 @@
 #include "externs.h"
 #include "interface.h"
 
-#if defined(TINYMUX_MODULES)
-
-#define NUM_CLASSES 4
-static MUX_CLASS_INFO netmux_classes[NUM_CLASSES] =
+static MUX_CLASS_INFO netmux_classes[] =
 {
     { CID_Log                },
     { CID_ServerEventsSource },
     { CID_StubSlaveProxy     },
-    { CID_QueryClient        }
+    { CID_QueryClient        },
+    { CID_Functions          }
 };
+#define NUM_CLASSES (sizeof(netmux_classes)/sizeof(netmux_classes[0]))
+
+DEFINE_FACTORY(CStubSlaveProxyFactory)
 
 extern "C" MUX_RESULT DCL_API netmux_GetClassObject(MUX_CID cid, MUX_IID iid, void **ppv)
 {
@@ -31,7 +30,7 @@ extern "C" MUX_RESULT DCL_API netmux_GetClassObject(MUX_CID cid, MUX_IID iid, vo
 
     if (CID_Log == cid)
     {
-        CLogFactory *pLogFactory = NULL;
+        CLogFactory *pLogFactory = nullptr;
         try
         {
             pLogFactory = new CLogFactory;
@@ -41,7 +40,7 @@ extern "C" MUX_RESULT DCL_API netmux_GetClassObject(MUX_CID cid, MUX_IID iid, vo
             ; // Nothing.
         }
 
-        if (NULL == pLogFactory)
+        if (nullptr == pLogFactory)
         {
             return MUX_E_OUTOFMEMORY;
         }
@@ -51,7 +50,7 @@ extern "C" MUX_RESULT DCL_API netmux_GetClassObject(MUX_CID cid, MUX_IID iid, vo
     }
     else if (CID_ServerEventsSource == cid)
     {
-        CServerEventsSourceFactory *pServerEventsSourceFactory = NULL;
+        CServerEventsSourceFactory *pServerEventsSourceFactory = nullptr;
         try
         {
             pServerEventsSourceFactory = new CServerEventsSourceFactory;
@@ -61,7 +60,7 @@ extern "C" MUX_RESULT DCL_API netmux_GetClassObject(MUX_CID cid, MUX_IID iid, vo
             ; // Nothing.
         }
 
-        if (NULL == pServerEventsSourceFactory)
+        if (nullptr == pServerEventsSourceFactory)
         {
             return MUX_E_OUTOFMEMORY;
         }
@@ -71,7 +70,7 @@ extern "C" MUX_RESULT DCL_API netmux_GetClassObject(MUX_CID cid, MUX_IID iid, vo
     }
     else if (CID_StubSlaveProxy == cid)
     {
-        CStubSlaveProxyFactory *pStubSlaveProxyFactory = NULL;
+        CStubSlaveProxyFactory *pStubSlaveProxyFactory = nullptr;
         try
         {
             pStubSlaveProxyFactory = new CStubSlaveProxyFactory;
@@ -81,7 +80,7 @@ extern "C" MUX_RESULT DCL_API netmux_GetClassObject(MUX_CID cid, MUX_IID iid, vo
             ; // Nothing.
         }
 
-        if (NULL == pStubSlaveProxyFactory)
+        if (nullptr == pStubSlaveProxyFactory)
         {
             return MUX_E_OUTOFMEMORY;
         }
@@ -91,7 +90,7 @@ extern "C" MUX_RESULT DCL_API netmux_GetClassObject(MUX_CID cid, MUX_IID iid, vo
     }
     else if (CID_QueryClient == cid)
     {
-        CQueryClientFactory *pQueryClientFactory = NULL;
+        CQueryClientFactory *pQueryClientFactory = nullptr;
         try
         {
             pQueryClientFactory = new CQueryClientFactory;
@@ -101,7 +100,7 @@ extern "C" MUX_RESULT DCL_API netmux_GetClassObject(MUX_CID cid, MUX_IID iid, vo
             ; // Nothing.
         }
 
-        if (NULL == pQueryClientFactory)
+        if (nullptr == pQueryClientFactory)
         {
             return MUX_E_OUTOFMEMORY;
         }
@@ -109,70 +108,76 @@ extern "C" MUX_RESULT DCL_API netmux_GetClassObject(MUX_CID cid, MUX_IID iid, vo
         mr = pQueryClientFactory->QueryInterface(iid, ppv);
         pQueryClientFactory->Release();
     }
+    else if (CID_Functions == cid)
+    {
+        CFunctionsFactory *pFunctionsFactory = nullptr;
+        try
+        {
+            pFunctionsFactory = new CFunctionsFactory;
+        }
+        catch (...)
+        {
+            ; // Nothing.
+        }
+
+        if (nullptr == pFunctionsFactory)
+        {
+            return MUX_E_OUTOFMEMORY;
+        }
+
+        mr = pFunctionsFactory->QueryInterface(iid, ppv);
+        pFunctionsFactory->Release();
+    }
+    return mr;
+}
+
+MUX_RESULT init_modules(void)
+{
+    MUX_RESULT mr = mux_InitModuleLibrary(IsMainProcess);
+    if (MUX_SUCCEEDED(mr))
+    {
+        mr = mux_RegisterClassObjects(NUM_CLASSES, netmux_classes, netmux_GetClassObject);
+    }
     return mr;
 }
 
 #ifdef STUB_SLAVE
 QUEUE_INFO Queue_In;
 QUEUE_INFO Queue_Out;
-#endif
 
-void init_modules(void)
+MUX_RESULT init_stubslave(void)
 {
-#ifdef STUB_SLAVE
     Pipe_InitializeQueueInfo(&Queue_In);
     Pipe_InitializeQueueInfo(&Queue_Out);
-    MUX_RESULT mr = mux_InitModuleLibrary(IsMainProcess, pipepump, &Queue_In, &Queue_Out);
-#else
-    MUX_RESULT mr = mux_InitModuleLibrary(IsMainProcess, NULL, NULL, NULL);
-#endif
-    if (MUX_SUCCEEDED(mr))
+    MUX_RESULT mr = mux_InitModuleLibraryPump(pipepump, &Queue_In, &Queue_Out);
+
+    if (nullptr != mudstate.pISlaveControl)
     {
-        mr = mux_RegisterClassObjects(NUM_CLASSES, netmux_classes, netmux_GetClassObject);
+        mudstate.pISlaveControl->Release();
+        mudstate.pISlaveControl = nullptr;
     }
 
+    mr = mux_CreateInstance(CID_StubSlave, nullptr, UseSlaveProcess, IID_ISlaveControl, (void **)&mudstate.pISlaveControl);
     if (MUX_SUCCEEDED(mr))
     {
         STARTLOG(LOG_ALWAYS, "INI", "LOAD");
-        log_printf(T("Registered netmux modules."));
+        log_printf(T("Opened interface for StubSlave management."));
         ENDLOG;
-
-#if defined(STUB_SLAVE)
-        if (NULL != mudstate.pISlaveControl)
-        {
-            mudstate.pISlaveControl->Release();
-            mudstate.pISlaveControl = NULL;
-        }
-
-        mr = mux_CreateInstance(CID_StubSlave, NULL, UseSlaveProcess, IID_ISlaveControl, (void **)&mudstate.pISlaveControl);
-        if (MUX_SUCCEEDED(mr))
-        {
-            STARTLOG(LOG_ALWAYS, "INI", "LOAD");
-            log_printf(T("Opened interface for StubSlave management."));
-            ENDLOG;
-        }
-        else
-        {
-            STARTLOG(LOG_ALWAYS, "INI", "LOAD");
-            log_printf(T("Failed to open interface for StubSlave management (%d)."), mr);
-            ENDLOG;
-        }
-#endif // STUB_SLAVE
     }
     else
     {
         STARTLOG(LOG_ALWAYS, "INI", "LOAD");
-        log_printf(T("Failed to register netmux modules (%d)."), mr);
+        log_printf(T("Failed to open interface for StubSlave management (%d)."), mr);
         ENDLOG;
     }
+    return mr;
 }
 
-void final_modules(void)
+void final_stubslave(void)
 {
     MUX_RESULT mr = MUX_S_OK;
 
-#if defined(STUB_SLAVE)
-    if (NULL != mudstate.pISlaveControl)
+    if (nullptr != mudstate.pISlaveControl)
     {
         mr = mudstate.pISlaveControl->ShutdownSlave();
         if (MUX_FAILED(mr))
@@ -183,10 +188,15 @@ void final_modules(void)
         }
 
         mudstate.pISlaveControl->Release();
-        mudstate.pISlaveControl = NULL;
+        mudstate.pISlaveControl = nullptr;
     }
+}
 #endif // STUB_SLAVE
 
+void final_modules(void)
+{
+    MUX_RESULT mr = MUX_S_OK;
+
     mr = mux_RevokeClassObjects(NUM_CLASSES, netmux_classes);
     if (MUX_FAILED(mr))
     {
@@ -203,212 +213,48 @@ void final_modules(void)
     mux_FinalizeModuleLibrary();
 }
 
-// CLog component which is not directly accessible.
-//
-CLog::CLog(void) : m_cRef(1)
-{
-}
-
-CLog::~CLog()
-{
-}
-
-MUX_RESULT CLog::QueryInterface(MUX_IID iid, void **ppv)
-{
-    if (mux_IID_IUnknown == iid)
-    {
-        *ppv = static_cast<mux_ILog *>(this);
-    }
-    else if (IID_ILog == iid)
-    {
-        *ppv = static_cast<mux_ILog *>(this);
-    }
-    else
-    {
-        *ppv = NULL;
-        return MUX_E_NOINTERFACE;
-    }
-    reinterpret_cast<mux_IUnknown *>(*ppv)->AddRef();
-    return MUX_S_OK;
-}
-
-UINT32 CLog::AddRef(void)
-{
-    m_cRef++;
-    return m_cRef;
-}
-
-UINT32 CLog::Release(void)
-{
-    m_cRef--;
-    if (0 == m_cRef)
-    {
-        delete this;
-        return 0;
-    }
-    return m_cRef;
-}
-
-bool CLog::start_log(int key, const UTF8 *primary, const UTF8 *secondary)
-{
-    if (  ((key) & mudconf.log_options) != 0
-       && ::start_log(primary, secondary))
-    {
-        return true;
-    }
-    else
-    {
-        return false;
-    }
-}
-
-void CLog::log_perror(const UTF8 *primary, const UTF8 *secondary, const UTF8 *extra, const UTF8 *failing_object)
-{
-    ::log_perror(primary, secondary, extra, failing_object);
-}
-
-void CLog::log_text(const UTF8 *text)
-{
-    ::log_text(text);
-}
-
-void CLog::log_number(int num)
-{
-    ::log_number(num);
-}
-
-void DCL_CDECL CLog::log_printf(const UTF8 *fmt, ...)
-{
-    va_list ap;
-    va_start(ap, fmt);
-    UTF8 aTempBuffer[SIZEOF_LOG_BUFFER];
-    size_t nString = mux_vsnprintf(aTempBuffer, SIZEOF_LOG_BUFFER, fmt, ap);
-    va_end(ap);
-    Log.WriteBuffer(nString, aTempBuffer);
-}
-
-void CLog::log_name(dbref target)
-{
-    ::log_name(target);
-}
-
-void CLog::log_name_and_loc(dbref player)
-{
-    ::log_name_and_loc(player);
-}
-
-void CLog::log_type_and_name(dbref thing)
-{
-    ::log_type_and_name(thing);
-}
-
-void CLog::end_log(void)
-{
-    ::end_log();
-}
-
-// Factory for CLog component which is not directly accessible.
-//
-CLogFactory::CLogFactory(void) : m_cRef(1)
-{
-}
-
-CLogFactory::~CLogFactory()
-{
-}
-
-MUX_RESULT CLogFactory::QueryInterface(MUX_IID iid, void **ppv)
-{
-    if (mux_IID_IUnknown == iid)
-    {
-        *ppv = static_cast<mux_IClassFactory *>(this);
-    }
-    else if (mux_IID_IClassFactory == iid)
-    {
-        *ppv = static_cast<mux_IClassFactory *>(this);
-    }
-    else
-    {
-        *ppv = NULL;
-        return MUX_E_NOINTERFACE;
-    }
-    reinterpret_cast<mux_IUnknown *>(*ppv)->AddRef();
-    return MUX_S_OK;
-}
-
-UINT32 CLogFactory::AddRef(void)
-{
-    m_cRef++;
-    return m_cRef;
-}
-
-UINT32 CLogFactory::Release(void)
-{
-    m_cRef--;
-    if (0 == m_cRef)
-    {
-        delete this;
-        return 0;
-    }
-    return m_cRef;
-}
-
-MUX_RESULT CLogFactory::CreateInstance(mux_IUnknown *pUnknownOuter, MUX_IID iid, void **ppv)
-{
-    // Disallow attempts to aggregate this component.
-    //
-    if (NULL != pUnknownOuter)
-    {
-        return MUX_E_NOAGGREGATION;
-    }
-
-    CLog *pLog = NULL;
-    try
-    {
-        pLog = new CLog;
-    }
-    catch (...)
-    {
-        ; // Nothing.
-    }
-
-    if (NULL == pLog)
-    {
-        return MUX_E_OUTOFMEMORY;
-    }
-
-    MUX_RESULT mr = pLog->QueryInterface(iid, ppv);
-    pLog->Release();
-    return mr;
-}
-
-MUX_RESULT CLogFactory::LockServer(bool bLock)
-{
-    UNUSED_PARAMETER(bLock);
-    return MUX_S_OK;
-}
-
 // CServerEventsSource component which is not directly accessible.
 //
-CServerEventsSource::CServerEventsSource(void) : m_cRef(1), m_pSink(NULL)
+class CServerEventsSource : public mux_IServerEventsControl
+{
+public:
+    // mux_IUnknown
+    //
+    virtual MUX_RESULT QueryInterface(MUX_IID iid, void **ppv);
+    virtual UINT32     AddRef(void);
+    virtual UINT32     Release(void);
+
+    // mux_IServerEventsControl
+    //
+    virtual MUX_RESULT Advise(mux_IServerEventsSink *pIServerEvents);
+
+    CServerEventsSource(void);
+    virtual ~CServerEventsSource();
+
+private:
+    UINT32 m_cRef;
+    mux_IServerEventsSink *m_pSink;
+};
+
+CServerEventsSource::CServerEventsSource(void) : m_cRef(1), m_pSink(nullptr)
 {
 }
 
-ServerEventsSinkNode *g_pServerEventsSinkListHead = NULL;
+ServerEventsSinkNode *g_pServerEventsSinkListHead = nullptr;
 
 CServerEventsSource::~CServerEventsSource()
 {
-    if (NULL != m_pSink)
+    if (nullptr != m_pSink)
     {
         ServerEventsSinkNode *p = g_pServerEventsSinkListHead;
-        ServerEventsSinkNode *q = NULL;
-        while (NULL != p)
+        ServerEventsSinkNode *q = nullptr;
+        while (nullptr != p)
         {
             if (p->pSink == m_pSink)
             {
                 // Unlink node p from list.
                 //
-                if (NULL == q)
+                if (nullptr == q)
                 {
                     g_pServerEventsSinkListHead = p->pNext;
                 }
@@ -416,12 +262,12 @@ CServerEventsSource::~CServerEventsSource()
                 {
                     q->pNext = p->pNext;
                 }
-                p->pNext = NULL;
+                p->pNext = nullptr;
 
                 // Free sink and node.
                 //
                 p->pSink->Release();
-                p->pSink = NULL;
+                p->pSink = nullptr;
                 delete p;
                 break;
             }
@@ -430,7 +276,7 @@ CServerEventsSource::~CServerEventsSource()
         }
 
         m_pSink->Release();
-        m_pSink = NULL;
+        m_pSink = nullptr;
     }
 }
 
@@ -446,7 +292,7 @@ MUX_RESULT CServerEventsSource::QueryInterface(MUX_IID iid, void **ppv)
     }
     else
     {
-        *ppv = NULL;
+        *ppv = nullptr;
         return MUX_E_NOINTERFACE;
     }
     reinterpret_cast<mux_IUnknown *>(*ppv)->AddRef();
@@ -472,7 +318,7 @@ UINT32 CServerEventsSource::Release(void)
 
 MUX_RESULT CServerEventsSource::Advise(mux_IServerEventsSink *pIServerEventsSink)
 {
-    if (NULL == pIServerEventsSink)
+    if (nullptr == pIServerEventsSink)
     {
         return MUX_E_INVALIDARG;
     }
@@ -481,7 +327,7 @@ MUX_RESULT CServerEventsSource::Advise(mux_IServerEventsSink *pIServerEventsSink
     // added again.
     //
     ServerEventsSinkNode *p = g_pServerEventsSinkListHead;
-    while (NULL != p)
+    while (nullptr != p)
     {
         if (p->pSink == pIServerEventsSink)
         {
@@ -491,7 +337,7 @@ MUX_RESULT CServerEventsSource::Advise(mux_IServerEventsSink *pIServerEventsSink
 
     // Allocate a list node.
     //
-    p = NULL;
+    p = nullptr;
     try
     {
         p = new ServerEventsSinkNode;
@@ -501,7 +347,7 @@ MUX_RESULT CServerEventsSource::Advise(mux_IServerEventsSink *pIServerEventsSink
         ; // Nothing.
     }
 
-    if (NULL == p)
+    if (nullptr == p)
     {
         return MUX_E_OUTOFMEMORY;
     }
@@ -540,7 +386,7 @@ MUX_RESULT CServerEventsSourceFactory::QueryInterface(MUX_IID iid, void **ppv)
     }
     else
     {
-        *ppv = NULL;
+        *ppv = nullptr;
         return MUX_E_NOINTERFACE;
     }
     reinterpret_cast<mux_IUnknown *>(*ppv)->AddRef();
@@ -568,12 +414,12 @@ MUX_RESULT CServerEventsSourceFactory::CreateInstance(mux_IUnknown *pUnknownOute
 {
     // Disallow attempts to aggregate this component.
     //
-    if (NULL != pUnknownOuter)
+    if (nullptr != pUnknownOuter)
     {
         return MUX_E_NOAGGREGATION;
     }
 
-    CServerEventsSource *pServerEventsSource = NULL;
+    CServerEventsSource *pServerEventsSource = nullptr;
     try
     {
         pServerEventsSource = new CServerEventsSource;
@@ -583,7 +429,7 @@ MUX_RESULT CServerEventsSourceFactory::CreateInstance(mux_IUnknown *pUnknownOute
         ; // Nothing.
     }
 
-    if (NULL == pServerEventsSource)
+    if (nullptr == pServerEventsSource)
     {
         return MUX_E_OUTOFMEMORY;
     }
@@ -601,7 +447,46 @@ MUX_RESULT CServerEventsSourceFactory::LockServer(bool bLock)
 
 // StubSlaveProxy component which is not directly accessible.
 //
-CStubSlaveProxy::CStubSlaveProxy(void) : m_cRef(1), m_nChannel(CHANNEL_INVALID), m_pModuleName(NULL)
+class CStubSlaveProxy : public mux_ISlaveControl, public mux_IMarshal
+{
+public:
+    // mux_IUnknown
+    //
+    virtual MUX_RESULT QueryInterface(MUX_IID iid, void **ppv);
+    virtual UINT32     AddRef(void);
+    virtual UINT32     Release(void);
+
+    // mux_IMarshal
+    //
+    virtual MUX_RESULT GetUnmarshalClass(MUX_IID riid, marshal_context ctx, MUX_CID *pcid);
+    virtual MUX_RESULT MarshalInterface(QUEUE_INFO *pqi, MUX_IID riid, void *pv, marshal_context ctx);
+    virtual MUX_RESULT UnmarshalInterface(QUEUE_INFO *pqi, MUX_IID riid, void **ppv);
+    virtual MUX_RESULT ReleaseMarshalData(QUEUE_INFO *pqi);
+    virtual MUX_RESULT DisconnectObject(void);
+
+    // mux_ISlaveControl
+    //
+#if defined(WINDOWS_FILES)
+    virtual MUX_RESULT AddModule(const UTF8 aModuleName[], const UTF16 aFileName[]);
+#elif defined(UNIX_FILES)
+    virtual MUX_RESULT AddModule(const UTF8 aModuleName[], const UTF8 aFileName[]);
+#endif // UNIX_FILES
+    virtual MUX_RESULT RemoveModule(const UTF8 aModuleName[]);
+    virtual MUX_RESULT ModuleInfo(int iModule, MUX_MODULE_INFO *pModuleInfo);
+    virtual MUX_RESULT ModuleMaintenance(void);
+    virtual MUX_RESULT ShutdownSlave(void);
+
+    CStubSlaveProxy(void);
+    MUX_RESULT FinalConstruct(void);
+    virtual ~CStubSlaveProxy();
+
+private:
+    UINT32 m_cRef;
+    UINT32 m_nChannel;
+    UTF8  *m_pModuleName;
+};
+
+CStubSlaveProxy::CStubSlaveProxy(void) : m_cRef(1), m_nChannel(CHANNEL_INVALID), m_pModuleName(nullptr)
 {
 }
 
@@ -630,7 +515,7 @@ MUX_RESULT CStubSlaveProxy::QueryInterface(MUX_IID iid, void **ppv)
     }
     else
     {
-        *ppv = NULL;
+        *ppv = nullptr;
         return MUX_E_NOINTERFACE;
     }
     reinterpret_cast<mux_IUnknown *>(*ppv)->AddRef();
@@ -674,10 +559,11 @@ MUX_RESULT CStubSlaveProxy::GetUnmarshalClass(MUX_IID riid, marshal_context ctx,
     return MUX_E_NOTIMPLEMENTED;
 }
 
-MUX_RESULT CStubSlaveProxy::MarshalInterface(QUEUE_INFO *pqi, MUX_IID riid, marshal_context ctx)
+MUX_RESULT CStubSlaveProxy::MarshalInterface(QUEUE_INFO *pqi, MUX_IID riid, void *pv, marshal_context ctx)
 {
     UNUSED_PARAMETER(pqi);
     UNUSED_PARAMETER(riid);
+    UNUSED_PARAMETER(pv);
     UNUSED_PARAMETER(ctx);
 
     // This should only be called on the component side.
@@ -851,10 +737,10 @@ MUX_RESULT CStubSlaveProxy::ModuleInfo(int iModule, MUX_MODULE_INFO *pModuleInfo
         if (  Pipe_GetBytes(&qiFrame, &nWanted, &ReturnFrame)
            && nWanted == sizeof(ReturnFrame))
         {
-            if (NULL != m_pModuleName)
+            if (nullptr != m_pModuleName)
             {
                 delete m_pModuleName;
-                m_pModuleName = NULL;
+                m_pModuleName = nullptr;
             }
 
             if (0 < ReturnFrame.nName)
@@ -868,7 +754,7 @@ MUX_RESULT CStubSlaveProxy::ModuleInfo(int iModule, MUX_MODULE_INFO *pModuleInfo
                     ; // Nothing.
                 }
 
-                if (NULL != m_pModuleName)
+                if (nullptr != m_pModuleName)
                 {
                     nWanted = ReturnFrame.nName;
                     if (  Pipe_GetBytes(&qiFrame, &nWanted, m_pModuleName)
@@ -891,7 +777,7 @@ MUX_RESULT CStubSlaveProxy::ModuleInfo(int iModule, MUX_MODULE_INFO *pModuleInfo
             else
             {
                 pModuleInfo->bLoaded = ReturnFrame.bLoaded;
-                pModuleInfo->pName   = NULL;
+                pModuleInfo->pName   = nullptr;
                 mr = ReturnFrame.mr;
             }
         }
@@ -1001,7 +887,7 @@ MUX_RESULT CStubSlaveProxyFactory::QueryInterface(MUX_IID iid, void **ppv)
     }
     else
     {
-        *ppv = NULL;
+        *ppv = nullptr;
         return MUX_E_NOINTERFACE;
     }
     reinterpret_cast<mux_IUnknown *>(*ppv)->AddRef();
@@ -1029,12 +915,12 @@ MUX_RESULT CStubSlaveProxyFactory::CreateInstance(mux_IUnknown *pUnknownOuter, M
 {
     // Disallow attempts to aggregate this component.
     //
-    if (NULL != pUnknownOuter)
+    if (nullptr != pUnknownOuter)
     {
         return MUX_E_NOAGGREGATION;
     }
 
-    CStubSlaveProxy *pStubSlaveProxy = NULL;
+    CStubSlaveProxy *pStubSlaveProxy = nullptr;
     try
     {
         pStubSlaveProxy = new CStubSlaveProxy;
@@ -1045,7 +931,7 @@ MUX_RESULT CStubSlaveProxyFactory::CreateInstance(mux_IUnknown *pUnknownOuter, M
     }
 
     MUX_RESULT mr;
-    if (NULL == pStubSlaveProxy)
+    if (nullptr == pStubSlaveProxy)
     {
         return MUX_E_OUTOFMEMORY;
     }
@@ -1072,6 +958,34 @@ MUX_RESULT CStubSlaveProxyFactory::LockServer(bool bLock)
 
 // CQueryClient component which is not directly accessible.
 //
+class CQueryClient : public mux_IQuerySink, public mux_IMarshal
+{
+public:
+    // mux_IUnknown
+    //
+    virtual MUX_RESULT QueryInterface(MUX_IID iid, void **ppv);
+    virtual UINT32     AddRef(void);
+    virtual UINT32     Release(void);
+
+    // mux_IMarshal
+    //
+    virtual MUX_RESULT GetUnmarshalClass(MUX_IID riid, marshal_context ctx, MUX_CID *pcid);
+    virtual MUX_RESULT MarshalInterface(QUEUE_INFO *pqi, MUX_IID riid, void *pv, marshal_context ctx);
+    virtual MUX_RESULT UnmarshalInterface(QUEUE_INFO *pqi, MUX_IID riid, void **ppv);
+    virtual MUX_RESULT ReleaseMarshalData(QUEUE_INFO *pqi);
+    virtual MUX_RESULT DisconnectObject(void);
+
+    // mux_IQuerySink
+    //
+    virtual MUX_RESULT Result(UINT32 iQueryHandle, UINT32 iError, QUEUE_INFO *pqiResultsSet);
+
+    CQueryClient(void);
+    virtual ~CQueryClient();
+
+private:
+    UINT32 m_cRef;
+};
+
 CQueryClient::CQueryClient(void) : m_cRef(1)
 {
 }
@@ -1096,7 +1010,7 @@ MUX_RESULT CQueryClient::QueryInterface(MUX_IID iid, void **ppv)
     }
     else
     {
-        *ppv = NULL;
+        *ppv = nullptr;
         return MUX_E_NOINTERFACE;
     }
     reinterpret_cast<mux_IUnknown *>(*ppv)->AddRef();
@@ -1124,7 +1038,7 @@ MUX_RESULT CQueryClient::GetUnmarshalClass(MUX_IID riid, marshal_context ctx, MU
 {
     UNUSED_PARAMETER(ctx);
 
-    if (NULL == pcid)
+    if (nullptr == pcid)
     {
         return MUX_E_INVALIDARG;
     }
@@ -1142,7 +1056,7 @@ MUX_RESULT CQueryClient::GetUnmarshalClass(MUX_IID riid, marshal_context ctx, MU
 MUX_RESULT CQueryClient_Call(CHANNEL_INFO *pci, QUEUE_INFO *pqi)
 {
     mux_IQuerySink *pIQuerySink = static_cast<mux_IQuerySink *>(pci->pInterface);
-    if (NULL == pIQuerySink)
+    if (nullptr == pIQuerySink)
     {
         return MUX_E_NOINTERFACE;
     }
@@ -1210,14 +1124,14 @@ MUX_RESULT CQueryClient_Disconnect(CHANNEL_INFO *pci, QUEUE_INFO *pqi)
     // Get our interface pointer from the channel.
     //
     mux_IUnknown *pIUnknown= static_cast<mux_IUnknown *>(pci->pInterface);
-    pci->pInterface = NULL;
+    pci->pInterface = nullptr;
 
     // Tear down our side of the communication.  Our callback functions will
     // no longer be called.
     //
     Pipe_FreeChannel(pci);
 
-    if (NULL != pIUnknown)
+    if (nullptr != pIUnknown)
     {
         pIUnknown->Release();
         return MUX_S_OK;
@@ -1228,12 +1142,12 @@ MUX_RESULT CQueryClient_Disconnect(CHANNEL_INFO *pci, QUEUE_INFO *pqi)
     }
 }
 
-MUX_RESULT CQueryClient::MarshalInterface(QUEUE_INFO *pqi, MUX_IID riid, marshal_context ctx)
+MUX_RESULT CQueryClient::MarshalInterface(QUEUE_INFO *pqi, MUX_IID riid, void *pv, marshal_context ctx)
 {
     // Parameter validation and initialization.
     //
     MUX_RESULT mr = MUX_S_OK;
-    if (NULL == pqi)
+    if (nullptr == pqi)
     {
         mr = MUX_E_INVALIDARG;
     }
@@ -1247,14 +1161,22 @@ MUX_RESULT CQueryClient::MarshalInterface(QUEUE_INFO *pqi, MUX_IID riid, marshal
     }
     else
     {
-        mux_IQuerySink *pIQuerySink = NULL;
-        mr = QueryInterface(IID_IQuerySink, (void **)&pIQuerySink);
+        mux_IQuerySink *pIQuerySink = nullptr;
+        if (nullptr == pv)
+        {
+            mr = QueryInterface(IID_IQuerySink, (void **)&pIQuerySink);
+        }
+        else
+        {
+            mux_IUnknown *pIUnknown = static_cast<mux_IUnknown *>(pv);
+            mr = pIUnknown->QueryInterface(IID_IQuerySink, (void **)&pIQuerySink);
+        }
         if (MUX_SUCCEEDED(mr))
         {
             // Construct a packet sufficient to allow the proxy to communicate with us.
             //
             CHANNEL_INFO *pChannel = Pipe_AllocateChannel(CQueryClient_Call, CQueryClient_Msg, CQueryClient_Disconnect);
-            if (NULL != pChannel)
+            if (nullptr != pChannel)
             {
                 pChannel->pInterface = pIQuerySink;
                 Pipe_AppendBytes(pqi, sizeof(pChannel->nChannel), (UTF8*)(&pChannel->nChannel));
@@ -1263,7 +1185,7 @@ MUX_RESULT CQueryClient::MarshalInterface(QUEUE_INFO *pqi, MUX_IID riid, marshal
             else
             {
                 pIQuerySink->Release();
-                pIQuerySink = NULL;
+                pIQuerySink = nullptr;
                 mr = MUX_E_OUTOFMEMORY;
             }
         }
@@ -1293,7 +1215,7 @@ MUX_RESULT CQueryClient::ReleaseMarshalData(QUEUE_INFO *pqi)
        && sizeof(nChannel) == nWanted)
     {
         CHANNEL_INFO *pChannel = Pipe_FindChannel(nChannel);
-        if (NULL != pChannel)
+        if (nullptr != pChannel)
         {
             CQueryClient_Disconnect(pChannel, pqi);
         }
@@ -1315,7 +1237,7 @@ MUX_RESULT CQueryClient::DisconnectObject(void)
 MUX_RESULT CQueryClient::Result(UINT32 hQuery, UINT32 iError, QUEUE_INFO *pqiResultsSet)
 {
 #if defined(STUB_SLAVE)
-    CResultsSet *prs = NULL;
+    CResultsSet *prs = nullptr;
     try
     {
         prs = new CResultsSet(pqiResultsSet);
@@ -1356,7 +1278,7 @@ MUX_RESULT CQueryClientFactory::QueryInterface(MUX_IID iid, void **ppv)
     }
     else
     {
-        *ppv = NULL;
+        *ppv = nullptr;
         return MUX_E_NOINTERFACE;
     }
     reinterpret_cast<mux_IUnknown *>(*ppv)->AddRef();
@@ -1384,12 +1306,12 @@ MUX_RESULT CQueryClientFactory::CreateInstance(mux_IUnknown *pUnknownOuter, MUX_
 {
     // Disallow attempts to aggregate this component.
     //
-    if (NULL != pUnknownOuter)
+    if (nullptr != pUnknownOuter)
     {
         return MUX_E_NOAGGREGATION;
     }
 
-    CQueryClient *pLog = NULL;
+    CQueryClient *pLog = nullptr;
     try
     {
         pLog = new CQueryClient;
@@ -1399,7 +1321,7 @@ MUX_RESULT CQueryClientFactory::CreateInstance(mux_IUnknown *pUnknownOuter, MUX_
         ; // Nothing.
     }
 
-    if (NULL == pLog)
+    if (nullptr == pLog)
     {
         return MUX_E_OUTOFMEMORY;
     }
@@ -1418,8 +1340,8 @@ MUX_RESULT CQueryClientFactory::LockServer(bool bLock)
 CResultsSet::CResultsSet(QUEUE_INFO *pqi) : m_cRef(1), m_nFields(0),
      m_nBlob(0), m_bLoaded(false), m_iError(QS_SUCCESS), m_nRows(0)
 {
-    m_pBlob = NULL;
-    m_pRows = NULL;
+    m_pBlob = nullptr;
+    m_pRows = nullptr;
     size_t nWanted = sizeof(m_nFields);
     if (  Pipe_GetBytes(pqi, &nWanted, &m_nFields)
        && nWanted == sizeof(m_nFields))
@@ -1442,7 +1364,7 @@ CResultsSet::CResultsSet(QUEUE_INFO *pqi) : m_cRef(1), m_nFields(0),
                 }
 
                 nWanted = m_nBlob;
-                if (  NULL == m_pBlob
+                if (  nullptr == m_pBlob
                    || !Pipe_GetBytes(pqi, &nWanted, m_pBlob)
                    || nWanted != m_nBlob)
                 {
@@ -1466,7 +1388,7 @@ CResultsSet::CResultsSet(QUEUE_INFO *pqi) : m_cRef(1), m_nFields(0),
                         ; // Nothing.
                     }
 
-                    if (NULL != m_pRows)
+                    if (nullptr != m_pRows)
                     {
                         int i, j;
                         UTF8 *p = m_pBlob;
@@ -1516,7 +1438,7 @@ const UTF8 *CResultsSet::FirstField(int iRow)
 {
     if (  0 <= iRow
        && iRow < m_nRows
-       && NULL != m_pRows
+       && nullptr != m_pRows
        && 0 < m_nFields)
     {
         m_pCurrentField = m_pRows[iRow];
@@ -1524,7 +1446,7 @@ const UTF8 *CResultsSet::FirstField(int iRow)
     }
     else
     {
-        m_pCurrentField = NULL;
+        m_pCurrentField = nullptr;
         m_iCurrentField = 1;
     }
     return m_pCurrentField;
@@ -1532,8 +1454,8 @@ const UTF8 *CResultsSet::FirstField(int iRow)
 
 const UTF8 *CResultsSet::NextField(void)
 {
-    const UTF8 *pField = NULL;
-    if (  NULL != m_pCurrentField
+    const UTF8 *pField = nullptr;
+    if (  nullptr != m_pCurrentField
        && 0 < m_nFields
        && m_iCurrentField < m_nFields)
     {
@@ -1549,16 +1471,16 @@ const UTF8 *CResultsSet::NextField(void)
 
 CResultsSet::~CResultsSet(void)
 {
-    if (NULL != m_pBlob)
+    if (nullptr != m_pBlob)
     {
         delete [] m_pBlob;
-        m_pBlob = NULL;
+        m_pBlob = nullptr;
     }
 
-    if (NULL != m_pRows)
+    if (nullptr != m_pRows)
     {
         delete [] m_pRows;
-        m_pRows = NULL;
+        m_pRows = nullptr;
     }
 }
 
@@ -1578,5 +1500,3 @@ UINT32 CResultsSet::AddRef(void)
     m_cRef++;
     return m_cRef;
 }
-
-#endif
