@@ -1,8 +1,6 @@
 /*! \file sample.cpp
  * \brief Sample Module
  *
- * $Id: sample.cpp 5476 2012-02-29 22:45:33Z brazilofmux $
- *
  */
 
 #include "../autoconf.h"
@@ -149,10 +147,12 @@ MUX_RESULT CSample::FinalConstruct(void)
     mr = mux_CreateInstance(CID_Log, NULL, UseSameProcess, IID_ILog, (void **)&m_pILog);
     if (MUX_SUCCEEDED(mr))
     {
-        if (m_pILog->start_log(LOG_ALWAYS, T("INI"), T("INFO")))
+        bool fStarted;
+        mr = m_pILog->start_log(&fStarted, LOG_ALWAYS, T("INI"), T("INFO")); 
+        if (MUX_SUCCEEDED(mr) && fStarted)
         {
-            m_pILog->log_printf(T("CSample::CSample()."));
-            m_pILog->end_log();
+            mr = m_pILog->log_text(T("CSample::CSample()." ENDLINE));
+            mr = m_pILog->end_log();
         }
     }
 
@@ -176,10 +176,12 @@ CSample::~CSample()
 {
     if (NULL != m_pILog)
     {
-        if (m_pILog->start_log(LOG_ALWAYS, T("INI"), T("INFO")))
+        bool fStarted;
+        MUX_RESULT mr = m_pILog->start_log(&fStarted, LOG_ALWAYS, T("INI"), T("INFO"));
+        if (MUX_SUCCEEDED(mr) && fStarted)
         {
-            m_pILog->log_printf(T("CSample::~CSample()."));
-            m_pILog->end_log();
+            mr = m_pILog->log_text(T("CSample::~CSample()." ENDLINE));
+            mr = m_pILog->end_log();
         }
 
         m_pILog->Release();
@@ -349,29 +351,32 @@ MUX_RESULT CSampleFactory::LockServer(bool bLock)
 //
 void CSample::startup(void)
 {
-    m_pILog->log_printf(T("Sample module sees CSample::startup event." ENDLINE));
+    MUX_RESULT mr = m_pILog->log_text(T("Sample module sees CSample::startup event." ENDLINE));
 
 #if 1
     ISum *pISum = NULL;
-    MUX_RESULT mr = mux_CreateInstance(CID_Sum, NULL, UseSlaveProcess, IID_ISum, (void **)&pISum);
+    mr = mux_CreateInstance(CID_Sum, NULL, UseSlaveProcess, IID_ISum, (void **)&pISum);
     if (MUX_SUCCEEDED(mr))
     {
         int sum;
         mr = pISum->Add(1,1, &sum);
         if (MUX_SUCCEEDED(mr))
         {
-            m_pILog->log_printf(T("ISum::Add(1,1) is %d." ENDLINE), sum);
+            mr = m_pILog->log_text(T("ISum::Add(1,1) is:"));
+            mr = m_pILog->log_number(sum);
         }
         else
         {
-            m_pILog->log_printf(T("Call to pISum->Add() failed with %d." ENDLINE), mr);
+            mr = m_pILog->log_text(T("Call to pISum->Add() failed with:."));
+            mr = m_pILog->log_number(mr);
         }
         pISum->Release();
         pISum = NULL;
     }
     else
     {
-        m_pILog->log_printf(T("CreateInstance returned %d." ENDLINE), mr);
+        mr = m_pILog->log_text(T("CreateInstance returned:"));
+        mr = m_pILog->log_number(mr);
     }
 #endif
 }
@@ -384,7 +389,7 @@ void CSample::startup(void)
 //
 void CSample::presync_database(void)
 {
-    m_pILog->log_printf(T("Sample module sees CSample::presync_database event." ENDLINE));
+    m_pILog->log_text(T("Sample module sees CSample::presync_database event." ENDLINE));
 }
 
 // Like the above routine except that it called from the SIGSEGV handler.
@@ -393,7 +398,7 @@ void CSample::presync_database(void)
 //
 void CSample::presync_database_sigsegv(void)
 {
-    m_pILog->log_printf(T("Sample module sees CSample::presync_database_sigsegv event." ENDLINE));
+    m_pILog->log_text(T("Sample module sees CSample::presync_database_sigsegv event." ENDLINE));
 }
 
 // This is called prior to the game database writing out it's own
@@ -416,7 +421,7 @@ void CSample::dump_database(int dump_type)
 {
     UNUSED_PARAMETER(dump_type);
 
-    m_pILog->log_printf(T("Sample module sees CSample::dump_database event." ENDLINE));
+    m_pILog->log_text(T("Sample module sees CSample::dump_database event." ENDLINE));
 }
 
 // The function is called when the dumping process has completed.
@@ -428,7 +433,7 @@ void CSample::dump_database(int dump_type)
 //
 void CSample::dump_complete_signal(void)
 {
-    m_pILog->log_printf(T("Sample module sees CSample::dump_complete_signal event." ENDLINE));
+    m_pILog->log_text(T("Sample module sees CSample::dump_complete_signal event." ENDLINE));
 }
 
 // Called when the game is shutting down, after the game database has
@@ -436,7 +441,7 @@ void CSample::dump_complete_signal(void)
 //
 void CSample::shutdown(void)
 {
-    m_pILog->log_printf(T("Sample module sees CSample::shutdown event." ENDLINE));
+    m_pILog->log_text(T("Sample module sees CSample::shutdown event." ENDLINE));
 }
 
 // Called after the database consistency check is completed.   Add
@@ -444,7 +449,7 @@ void CSample::shutdown(void)
 //
 void CSample::dbck(void)
 {
-    m_pILog->log_printf(T("Sample module sees CSample::dbck event." ENDLINE));
+    m_pILog->log_text(T("Sample module sees CSample::dbck event." ENDLINE));
 }
 
 // Called when a player connects or creates at the connection screen.
@@ -457,7 +462,7 @@ void CSample::connect(dbref player, int isnew, int num)
     UNUSED_PARAMETER(isnew);
     UNUSED_PARAMETER(num);
 
-    m_pILog->log_printf(T("Sample module sees CSample::connect event." ENDLINE));
+    m_pILog->log_text(T("Sample module sees CSample::connect event." ENDLINE));
 }
 
 // Called when player disconnects from the game.  The parameter 'num' is
@@ -469,7 +474,7 @@ void CSample::disconnect(dbref player, int num)
     UNUSED_PARAMETER(player);
     UNUSED_PARAMETER(num);
 
-    m_pILog->log_printf(T("Sample module sees CSample::disconnect event." ENDLINE));
+    m_pILog->log_text(T("Sample module sees CSample::disconnect event." ENDLINE));
 }
 
 // Called after any object type is created.
@@ -478,7 +483,7 @@ void CSample::data_create(dbref object)
 {
     UNUSED_PARAMETER(object);
 
-    m_pILog->log_printf(T("Sample module sees CSample::data_create event." ENDLINE));
+    m_pILog->log_text(T("Sample module sees CSample::data_create event." ENDLINE));
 }
 
 // Called when an object is cloned.  clone is the new object created
@@ -489,7 +494,7 @@ void CSample::data_clone(dbref clone, dbref source)
     UNUSED_PARAMETER(clone);
     UNUSED_PARAMETER(source);
 
-    m_pILog->log_printf(T("Sample module sees CSample::data_clone event." ENDLINE));
+    m_pILog->log_text(T("Sample module sees CSample::data_clone event." ENDLINE));
 }
 
 // Called when the object is truly destroyed, not just set GOING
@@ -498,7 +503,7 @@ void CSample::data_free(dbref object)
 {
     UNUSED_PARAMETER(object);
 
-    m_pILog->log_printf(T("Sample module sees CSample::data_free event." ENDLINE));
+    m_pILog->log_text(T("Sample module sees CSample::data_free event." ENDLINE));
 }
 
 // SumProxy component which is not directly accessible.
@@ -578,10 +583,11 @@ MUX_RESULT CSumProxy::GetUnmarshalClass(MUX_IID riid, marshal_context ctx, MUX_C
     return MUX_E_NOTIMPLEMENTED;
 }
 
-MUX_RESULT CSumProxy::MarshalInterface(QUEUE_INFO *pqi, MUX_IID riid, marshal_context ctx)
+MUX_RESULT CSumProxy::MarshalInterface(QUEUE_INFO *pqi, MUX_IID riid, void *pv, marshal_context ctx)
 {
     UNUSED_PARAMETER(pqi);
     UNUSED_PARAMETER(riid);
+    UNUSED_PARAMETER(pv);
     UNUSED_PARAMETER(ctx);
 
     // This should only be called on the component side.
