@@ -1,8 +1,6 @@
 /*! \file object.cpp
  * \brief Low-level object manipulation routines.
  *
- * $Id: object.cpp 4573 2010-05-01 20:09:36Z brazilofmux $
- *
  */
 
 #include "copyright.h"
@@ -192,7 +190,7 @@ static void update_newobjects(dbref player, dbref object_num, int object_type)
     //
     int i;
     dbref object_list[4];
-    if (  NULL == newobject_string
+    if (  nullptr == newobject_string
        || '\0' == newobject_string[0])
     {
         for (i = 0; i < 4; i++)
@@ -208,7 +206,7 @@ static void update_newobjects(dbref player, dbref object_num, int object_type)
 
         UTF8* ptr;
         for ( ptr = mux_strtok_parse(&tts), i = 0;
-              NULL != ptr && i < 4;
+              nullptr != ptr && i < 4;
               ptr = mux_strtok_parse(&tts), i++)
         {
             object_list[i] = mux_atol(ptr);
@@ -507,9 +505,9 @@ dbref create_obj(dbref player, int objtype, const UTF8 *name, int cost)
     s_Owner(obj, (self_owned ? obj : owner));
     s_Pennies(obj, value);
     Unmark(obj);
-    pValidName = munge_space(pValidName);
-    s_Name(obj, pValidName);
-    free_lbuf(pValidName);
+    buff = munge_space(pValidName);
+    s_Name(obj, buff);
+    free_lbuf(buff); buff = nullptr;
     db[obj].cpu_time_used.Set100ns(0);
 
     db[obj].tThrottleExpired.Set100ns(0);
@@ -564,7 +562,7 @@ static void destroy_bad_obj(dbref obj)
         ReleaseAllResources(obj);
     }
     atr_free(obj);
-    s_Name(obj, NULL);
+    s_Name(obj, nullptr);
     s_Flags(obj, FLAG_WORD1, (TYPE_GARBAGE | GOING));
     s_Flags(obj, FLAG_WORD2, 0);
     s_Flags(obj, FLAG_WORD3, 0);
@@ -684,7 +682,7 @@ void destroy_obj(dbref obj)
         ReleaseAllResources(obj);
     }
     atr_free(obj);
-    s_Name(obj, NULL);
+    s_Name(obj, nullptr);
     s_Flags(obj, FLAG_WORD1, (TYPE_GARBAGE | GOING));
     s_Flags(obj, FLAG_WORD2, 0);
     s_Flags(obj, FLAG_WORD3, 0);
@@ -702,14 +700,12 @@ void destroy_obj(dbref obj)
 
     local_data_free(obj);
 
-#if defined(TINYMUX_MODULES)
     ServerEventsSinkNode *p = g_pServerEventsSinkListHead;
-    while (NULL != p)
+    while (nullptr != p)
     {
         p->pSink->data_free(obj);
         p = p->pNext;
     }
-#endif // TINYMUX_MODULES
 }
 
 /*
@@ -1393,7 +1389,7 @@ static void check_dead_refs(void)
  * *      Location GOING                                  - skip it.
  * *      Location not a PLAYER, ROOM, or THING           - skip it.
  * *      Location already visited                        - skip it.
- * *      Exit/next pointer not in database               - NULL it.
+ * *      Exit/next pointer not in database               - nullptr it.
  * *      Member is not an EXIT                           - terminate chain.
  * *      Member is GOING                                 - destroy exit.
  * *      Member already checked (is in another list)     - terminate chain.
@@ -1603,7 +1599,7 @@ static void check_exit_chains(void)
  * *      Location GOING                                  - skip it.
  * *      Location not a PLAYER, ROOM, or THING           - skip it.
  * *      Location already visited                        - skip it.
- * *      Contents/next pointer not in database           - NULL it.
+ * *      Contents/next pointer not in database           - nullptr it.
  * *      Member is not an PLAYER or THING                - terminate chain.
  * *      Member is GOING                                 - destroy exit.
  * *      Member already checked (is in another list)     - terminate chain.
@@ -1891,27 +1887,23 @@ void do_dbck(dbref executor, dbref caller, dbref enactor, int eval, int key)
     purge_going();
     make_freelist();
     scheduler.Shrink();
-#if defined(TINYMUX_MODULES)
     mux_ModuleMaintenance();
 #if defined(STUB_SLAVE)
-    if (NULL != mudstate.pISlaveControl)
+    if (nullptr != mudstate.pISlaveControl)
     {
         mudstate.pISlaveControl->ModuleMaintenance();
     }
 #endif // STUB_SLAVE
-#endif // TINYMUX_MODULES
 
     // Allow the local extensions to do data checks.
     //
     local_dbck();
-#if defined(TINYMUX_MODULES)
     ServerEventsSinkNode *p = g_pServerEventsSinkListHead;
-    while (NULL != p)
+    while (nullptr != p)
     {
         p->pSink->dbck();
         p = p->pNext;
     }
-#endif // TINYMUX_MODULES
 
     if (  !mudstate.bStandAlone
        && executor != NOTHING
