@@ -1,8 +1,6 @@
 /*! \file predicates.cpp
  * \brief Miscellaneous commands and functions.
  *
- * $Id: predicates.cpp 5881 2016-12-31 04:09:57Z sdennis $
- *
  * In theory, most of these functions could plausibly be called
  * "predicates", either because they determine some boolean property
  * of the input, or because they perform some action that makes them
@@ -14,7 +12,7 @@
 #include "config.h"
 #include "externs.h"
 
-#include <signal.h>
+#include <csignal>
 
 #include "attrs.h"
 #include "command.h"
@@ -326,6 +324,26 @@ bool IsRestricted(const UTF8 *pName, int charset)
         {
             bAllowed = true;
         }
+        else if (  (ALLOW_CHARSET_HANGUL & charset)
+                && mux_ishangul(pName))
+        {
+            bAllowed = true;
+        }
+        else if (  (ALLOW_CHARSET_HIRAGANA & charset)
+                && mux_ishiragana(pName))
+        {
+            bAllowed = true;
+        }
+        else if (  (ALLOW_CHARSET_KANJI & charset)
+                && mux_iskanji(pName))
+        {
+            bAllowed = true;
+        }
+        else if (  (ALLOW_CHARSET_KATAKANA & charset)
+                && mux_iskatakana(pName))
+        {
+            bAllowed = true;
+        }
 
         if (!bAllowed)
         {
@@ -349,7 +367,7 @@ UTF8 *MakeCanonicalObjectName(const UTF8 *pName, size_t *pnName, bool *pbValid,
 
     if (!pName)
     {
-        return NULL;
+        return nullptr;
     }
 
     // Build up what the real name would be. If we pass all the
@@ -362,7 +380,7 @@ UTF8 *MakeCanonicalObjectName(const UTF8 *pName, size_t *pnName, bool *pbValid,
     //
     if (0 == fldLen.m_column)
     {
-        return NULL;
+        return nullptr;
     }
 
     // Get the stripped version (Visible parts without color info).
@@ -377,7 +395,7 @@ UTF8 *MakeCanonicalObjectName(const UTF8 *pName, size_t *pnName, bool *pbValid,
        || mux_isspace(pStripped[0])
        || mux_isspace(pStripped[nStripped-1]))
     {
-        return NULL;
+        return nullptr;
     }
 
     // Only printable characters besides ARG_DELIMITER, AND_TOKEN,
@@ -388,7 +406,7 @@ UTF8 *MakeCanonicalObjectName(const UTF8 *pName, size_t *pnName, bool *pbValid,
     {
         if (!mux_isobjectname(p))
         {
-            return NULL;
+            return nullptr;
         }
         p = utf8_NextCodePoint(p);
     }
@@ -399,12 +417,12 @@ UTF8 *MakeCanonicalObjectName(const UTF8 *pName, size_t *pnName, bool *pbValid,
        || (nStripped == 4 && (  memcmp("home", pStripped, 4) == 0
                              || memcmp("here", pStripped, 4) == 0)))
     {
-        return NULL;
+        return nullptr;
     }
 
     if (IsRestricted(pStripped, charset))
     {
-        return NULL;
+        return nullptr;
     }
 
     *pnName = fldLen.m_byte;
@@ -423,7 +441,7 @@ UTF8 *MakeCanonicalExitName(const UTF8 *pName, size_t *pnName, bool *pbValid)
 
     if (!pName)
     {
-        return NULL;
+        return nullptr;
     }
 
     mux_strncpy(Buf, pName, mux_strlen(pName));
@@ -444,7 +462,7 @@ UTF8 *MakeCanonicalExitName(const UTF8 *pName, size_t *pnName, bool *pbValid)
     bool bHaveDisplay = false;
     for (ptr = mux_strtok_parse(&tts); ptr; ptr = mux_strtok_parse(&tts))
     {
-        UTF8 *pTrimmedSegment = NULL;
+        UTF8 *pTrimmedSegment = nullptr;
         if (bHaveDisplay)
         {
             // No color allowed in segments after the first one.
@@ -481,9 +499,10 @@ UTF8 *MakeCanonicalExitName(const UTF8 *pName, size_t *pnName, bool *pbValid)
                 }
             }
         }
+        free_lbuf(pTrimmedSegment);
+        pTrimmedSegment = nullptr;
     }
 
-
     *pbValid = bHaveDisplay;
     if (!bHaveDisplay)
     {
@@ -575,7 +594,7 @@ bool ValidatePlayerName(const UTF8 *pName)
 
 bool ok_password(const UTF8 *password, const UTF8 **pmsg)
 {
-    *pmsg = NULL;
+    *pmsg = nullptr;
 
     if (*password == '\0')
     {
@@ -739,7 +758,7 @@ void do_switch
         *bp = '\0';
         if (wild_match(buff, expr))
         {
-            UTF8 *tbuf = replace_tokens(args[a+1], NULL, NULL, expr);
+            UTF8 *tbuf = replace_tokens(args[a+1], nullptr, nullptr, expr);
             wait_que(executor, caller, enactor, eval, false, lta, NOTHING, 0,
                 tbuf,
                 ncargs, cargs,
@@ -754,7 +773,7 @@ void do_switch
        && !bAny
        && args[a])
     {
-        UTF8 *tbuf = replace_tokens(args[a], NULL, NULL, expr);
+        UTF8 *tbuf = replace_tokens(args[a], nullptr, nullptr, expr);
         wait_que(executor, caller, enactor, eval, false, lta, NOTHING, 0,
             tbuf,
             ncargs, cargs,
@@ -882,7 +901,7 @@ void do_addcommand
     {
         // Don't allow the same (thing,atr) in the list.
         //
-        for (nextp = old->addent; nextp != NULL; nextp = nextp->next)
+        for (nextp = old->addent; nextp != nullptr; nextp = nextp->next)
         {
             if (  nextp->thing == thing
                && nextp->atr == pattr->number)
@@ -912,7 +931,7 @@ void do_addcommand
             hashdeleteLEN(pName, strlen((char *)pName), &mudstate.command_htab);
         }
 
-        cmd = NULL;
+        cmd = nullptr;
         try
         {
             cmd = new CMDENT;
@@ -923,7 +942,7 @@ void do_addcommand
         }
         ISOUTOFMEMORY(cmd);
         cmd->cmdname = StringClone(pName);
-        cmd->switches = NULL;
+        cmd->switches = nullptr;
         cmd->perms = 0;
         cmd->extra = 0;
         if (  old
@@ -941,7 +960,7 @@ void do_addcommand
         add->thing = thing;
         add->atr = pattr->number;
         add->name = StringClone(pName);
-        add->next = NULL;
+        add->next = nullptr;
         cmd->addent = add;
 
         hashaddLEN(pName, strlen((char *)pName), cmd, &mudstate.command_htab);
@@ -995,7 +1014,7 @@ void do_listcommands(dbref player, dbref caller, dbref enactor, int eval,
             // If it's already found in the hash table, and it's being added
             // using the same object and attribute...
             //
-            for (nextp = old->addent; nextp != NULL; nextp = nextp->next)
+            for (nextp = old->addent; nextp != nullptr; nextp = nextp->next)
             {
                 ATTR *ap = (ATTR *)atr_num(nextp->atr);
                 const UTF8 *pName = T("(WARNING: Bad Attribute Number)");
@@ -1017,13 +1036,13 @@ void do_listcommands(dbref player, dbref caller, dbref enactor, int eval,
         UTF8 *pKeyName;
         int  nKeyName;
         for (old = (CMDENT *)hash_firstkey(&mudstate.command_htab, &nKeyName, &pKeyName);
-             old != NULL;
+             old != nullptr;
              old = (CMDENT *)hash_nextkey(&mudstate.command_htab, &nKeyName, &pKeyName))
         {
             if (old->callseq & CS_ADDED)
             {
                 pKeyName[nKeyName] = '\0';
-                for (nextp = old->addent; nextp != NULL; nextp = nextp->next)
+                for (nextp = old->addent; nextp != nullptr; nextp = nextp->next)
                 {
                     if (strcmp((char *)pKeyName, (char *)nextp->name) != 0)
                     {
@@ -1102,7 +1121,7 @@ void do_delcommand
     UTF8  *pCased = mux_strlwr(name, nCased);
 
     CMDENT *old, *cmd;
-    ADDENT *prev = NULL, *nextp;
+    ADDENT *prev = nullptr, *nextp;
     old = (CMDENT *)hashfindLEN(pCased, nCased, &mudstate.command_htab);
 
     if (  old
@@ -1115,13 +1134,13 @@ void do_delcommand
         {
             // Delete all @addcommand'ed associations with the given name.
             //
-            for (prev = old->addent; prev != NULL; prev = nextp)
+            for (prev = old->addent; prev != nullptr; prev = nextp)
             {
                 nextp = prev->next;
                 MEMFREE(prev->name);
-                prev->name = NULL;
+                prev->name = nullptr;
                 MEMFREE(prev);
-                prev = NULL;
+                prev = nullptr;
             }
             hashdeleteLEN(pCased, nCased, &mudstate.command_htab);
             cmd = (CMDENT *)hashfindLEN(p__Name, n__Name, &mudstate.command_htab);
@@ -1144,9 +1163,9 @@ void do_delcommand
                 //
             }
             MEMFREE(old->cmdname);
-            old->cmdname = NULL;
+            old->cmdname = nullptr;
             MEMFREE(old);
-            old = NULL;
+            old = nullptr;
             cache_prefix_cmds();
             notify(player, T("Done."));
         }
@@ -1154,13 +1173,13 @@ void do_delcommand
         {
             // Remove only the (name,thing,atr) association.
             //
-            for (nextp = old->addent; nextp != NULL; nextp = nextp->next)
+            for (nextp = old->addent; nextp != nullptr; nextp = nextp->next)
             {
                 if (  nextp->thing == thing
                    && nextp->atr == atr)
                 {
                     MEMFREE(nextp->name);
-                    nextp->name = NULL;
+                    nextp->name = nullptr;
                     if (!prev)
                     {
                         if (!nextp->next)
@@ -1186,22 +1205,22 @@ void do_delcommand
                                     &mudstate.command_htab);
                             }
                             MEMFREE(old->cmdname);
-                            old->cmdname = NULL;
+                            old->cmdname = nullptr;
                             MEMFREE(old);
-                            old = NULL;
+                            old = nullptr;
                         }
                         else
                         {
                             old->addent = nextp->next;
                             MEMFREE(nextp);
-                            nextp = NULL;
+                            nextp = nullptr;
                         }
                     }
                     else
                     {
                         prev->next = nextp->next;
                         MEMFREE(nextp);
-                        nextp = NULL;
+                        nextp = nullptr;
                     }
                     cache_prefix_cmds();
                     notify(player, T("Done."));
@@ -1233,18 +1252,18 @@ void handle_prog(DESC *d, UTF8 *message)
     {
         do_command(d, message + 1);
 
-        if (d->program_data != NULL)
+        if (d->program_data != nullptr)
         {
             queue_string(d, tprintf(T("%s>%s "), COLOR_INTENSE, COLOR_RESET));
 
-            if (OPTION_YES == UsState(d, TELNET_EOR))
+            if (OPTION_YES == us_state(d, TELNET_EOR))
             {
                 // Use telnet protocol's EOR command to show prompt.
                 //
                 const UTF8 aEOR[2] = { NVT_IAC, NVT_EOR };
                 queue_write_LEN(d, aEOR, sizeof(aEOR));
             }
-            else if (OPTION_YES != UsState(d, TELNET_SGA))
+            else if (OPTION_YES != us_state(d, TELNET_SGA))
             {
                 // Use telnet protocol's GOAHEAD command to show prompt.
                 //
@@ -1277,16 +1296,16 @@ void handle_prog(DESC *d, UTF8 *message)
             if (program->wait_regs[i])
             {
                 RegRelease(program->wait_regs[i]);
-                program->wait_regs[i] = NULL;
+                program->wait_regs[i] = nullptr;
             }
         }
 
-        // Set info for all player descriptors to NULL
+        // Set info for all player descriptors to nullptr
         //
         DESC_ITER_PLAYER(d->player, all)
         {
             mux_assert(program == all->program_data);
-            all->program_data = NULL;
+            all->program_data = nullptr;
         }
 
         MEMFREE(program);
@@ -1337,7 +1356,7 @@ void do_quitprog(dbref player, dbref caller, dbref enactor, int eval, int key, U
     bool isprog = false;
     DESC_ITER_PLAYER(doer, d)
     {
-        if (NULL != d->program_data)
+        if (nullptr != d->program_data)
         {
             isprog = true;
         }
@@ -1361,16 +1380,16 @@ void do_quitprog(dbref player, dbref caller, dbref enactor, int eval, int key, U
             if (program->wait_regs[i])
             {
                 RegRelease(program->wait_regs[i]);
-                program->wait_regs[i] = NULL;
+                program->wait_regs[i] = nullptr;
             }
         }
 
-        // Set info for all player descriptors to NULL.
+        // Set info for all player descriptors to nullptr.
         //
         DESC_ITER_PLAYER(doer, d)
         {
             mux_assert(program == d->program_data);
-            d->program_data = NULL;
+            d->program_data = nullptr;
         }
 
         MEMFREE(program);
@@ -1435,7 +1454,7 @@ void do_prog
     DESC *d;
     DESC_ITER_PLAYER(doer, d)
     {
-        if (d->program_data != NULL)
+        if (d->program_data != nullptr)
         {
             notify(player, T("Input already pending."));
             return;
@@ -1463,7 +1482,7 @@ void do_prog
         int   aflags;
         int   lev;
         dbref parent;
-        UTF8 *pBuffer = NULL;
+        UTF8 *pBuffer = nullptr;
         bool bFound = false;
         ITER_PARENTS(thing, parent, lev)
         {
@@ -1523,14 +1542,14 @@ void do_prog
 
         queue_string(d, tprintf(T("%s>%s "), COLOR_INTENSE, COLOR_RESET));
 
-        if (OPTION_YES == UsState(d, TELNET_EOR))
+        if (OPTION_YES == us_state(d, TELNET_EOR))
         {
             // Use telnet protocol's EOR command to show prompt.
             //
             const UTF8 aEOR[2] = { NVT_IAC, NVT_EOR };
             queue_write_LEN(d, aEOR, sizeof(aEOR));
         }
-        else if (OPTION_YES != UsState(d, TELNET_SGA))
+        else if (OPTION_YES != us_state(d, TELNET_SGA))
         {
             // Use telnet protocol's GOAHEAD command to show prompt.
             //
@@ -1595,15 +1614,16 @@ void do_restart(dbref executor, dbref caller, dbref enactor, int eval, int key)
 #endif
 
     local_presync_database();
-#if defined(TINYMUX_MODULES)
     ServerEventsSinkNode *p = g_pServerEventsSinkListHead;
-    while (NULL != p)
+    while (nullptr != p)
     {
         p->pSink->presync_database();
         p = p->pNext;
     }
+#if defined(STUB_SLAVE)
+    final_stubslave();
+#endif // STUB_SLAVE
     final_modules();
-#endif // TINYMUX_MODULES
 
 #ifndef MEMORY_BASED
     al_store();
@@ -1629,10 +1649,10 @@ void do_restart(dbref executor, dbref caller, dbref enactor, int eval, int key)
 
 #ifdef GAME_DOOFERMUX
     execl("bin/netmux", mudconf.mud_name, "-c", mudconf.config_file, "-p",
-        mudconf.pid_file, "-e", mudconf.log_dir, (char *)NULL);
+        mudconf.pid_file, "-e", mudconf.log_dir, (char *)nullptr);
 #else
     execl("bin/netmux", "netmux", "-c", mudconf.config_file, "-p",
-        mudconf.pid_file, "-e", mudconf.log_dir, (char *)NULL);
+        mudconf.pid_file, "-e", mudconf.log_dir, (char *)nullptr);
 #endif // GAME_DOOFERMUX
     mux_assert(false);
 #endif // UNIX_PROCESSES
@@ -1755,7 +1775,7 @@ dbref match_possessed(dbref player, dbref thing, UTF8 *target, dbref dflt, bool
         //
         place = target;
         target = (UTF8 *)strchr((char *)place, '\'');
-        if (  target == NULL
+        if (  target == nullptr
            || !*target)
         {
             return dflt;
@@ -1941,7 +1961,7 @@ bool parse_thing_slash(dbref player, const UTF8 *thing, const UTF8 **after, dbre
     //
     if (thing[i] == '\0')
     {
-        *after = NULL;
+        *after = nullptr;
         *it = NOTHING;
         return false;
     }
@@ -1997,7 +2017,7 @@ bool get_obj_and_lock(dbref player, const UTF8 *what, dbref *it, ATTR **attr, UT
     // Get the attribute definition, fail if not found.
     //
     *attr = atr_num(anum);
-    if (NULL == *attr)
+    if (nullptr == *attr)
     {
         safe_str(T("#-1 LOCK NOT FOUND"), errmsg, bufc);
         return false;
@@ -2029,8 +2049,23 @@ bool bCanReadAttr(dbref executor, dbref target, ATTR *tattr, bool bCheckParent)
         atr_get_info(target, tattr->number, &aowner, &aflags);
     }
 
+    int test_flags = tattr->flags;
+
+    if (mudstate.attrperm_list)
+    {
+        ATTRPERM *perm_walk = mudstate.attrperm_list;
+        while (nullptr != perm_walk)
+        {
+            if (quick_wild(perm_walk->wildcard, tattr->name))
+            {
+                test_flags |= perm_walk->flags;
+            }
+            perm_walk = perm_walk->next;
+        }
+    }
+
     int mAllow = AF_VISUAL;
-    if (  (tattr->flags & mAllow)
+    if (  (test_flags & mAllow)
        || (aflags & mAllow))
     {
         if (  mudstate.bStandAlone
@@ -2060,7 +2095,7 @@ bool bCanReadAttr(dbref executor, dbref target, ATTR *tattr, bool bCheckParent)
     }
     if (mDeny)
     {
-        if (  (tattr->flags & mDeny)
+        if (  (test_flags & mDeny)
            || (aflags & mDeny))
         {
             return false;
@@ -2103,12 +2138,27 @@ bool bCanSetAttr(dbref executor, dbref target, ATTR *tattr)
 
     dbref aowner;
     int aflags;
-    if (  (tattr->flags & mDeny)
+    bool info = atr_get_info(target, tattr->number, &aowner, &aflags);
+    int test_flags = tattr->flags;
+
+    if (mudstate.attrperm_list)
+    {
+        ATTRPERM *perm_walk = mudstate.attrperm_list;
+        while (nullptr != perm_walk)
+        {
+            if (quick_wild(perm_walk->wildcard,tattr->name))
+            {
+                test_flags |= perm_walk->flags;
+            }
+            perm_walk = perm_walk->next;
+        }
+    }
+
+    if (  (test_flags & mDeny)
 #ifdef FIRANMUX
        || Immutable(target)
 #endif
-       || (  atr_get_info(target, tattr->number, &aowner, &aflags)
-          && (aflags & mDeny)))
+       || (info && (aflags & mDeny)))
     {
         return false;
     }
@@ -2144,8 +2194,24 @@ bool bCanLockAttr(dbref executor, dbref target, ATTR *tattr)
 
     dbref aowner;
     int aflags;
-    if (  (tattr->flags & mDeny)
-       || !atr_get_info(target, tattr->number, &aowner, &aflags)
+    bool info = atr_get_info(target, tattr->number, &aowner, &aflags);
+    int test_flags = tattr->flags;
+
+    if (mudstate.attrperm_list)
+    {
+        ATTRPERM *perm_walk = mudstate.attrperm_list;
+        while (nullptr != perm_walk)
+        {
+            if (quick_wild(perm_walk->wildcard,tattr->name))
+            {
+                test_flags |= perm_walk->flags;
+            }
+            perm_walk = perm_walk->next;
+        }
+    }
+
+    if (  (test_flags & mDeny)
+       || !info
        || (aflags & mDeny))
     {
         return false;
@@ -2424,7 +2490,7 @@ void did_it(dbref player, dbref thing, int what, const UTF8 *def, int owhat,
             const UTF8 *odef, int awhat, int ctrl_flags,
             const UTF8 *args[], int nargs)
 {
-    if (MuxAlarm.bAlarmed)
+    if (alarm_clock.alarmed)
     {
         return;
     }
@@ -2444,7 +2510,7 @@ void did_it(dbref player, dbref thing, int what, const UTF8 *def, int owhat,
     //
 
     bool need_pres = false;
-    reg_ref **preserve = NULL;
+    reg_ref **preserve = nullptr;
 
     // message to player.
     //
@@ -2725,8 +2791,8 @@ void do_verb(dbref executor, dbref caller, dbref enactor, int eval, int key,
     int what = -1;
     int owhat = -1;
     int awhat = -1;
-    const UTF8 *whatd = NULL;
-    const UTF8 *owhatd = NULL;
+    const UTF8 *whatd = nullptr;
+    const UTF8 *owhatd = nullptr;
     int nxargs = 0;
     dbref aowner = NOTHING;
     int aflags = NOTHING;
@@ -2738,7 +2804,7 @@ void do_verb(dbref executor, dbref caller, dbref enactor, int eval, int key,
         // Get arguments.
         //
         parse_arglist(victim, actor, actor, args[6],
-            EV_STRIP_LS | EV_STRIP_TS, xargs, 10, NULL, 0, &nxargs);
+            EV_STRIP_LS | EV_STRIP_TS, xargs, 10, nullptr, 0, &nxargs);
 
     case 6:
         // Get action attribute.
@@ -2788,7 +2854,7 @@ void do_verb(dbref executor, dbref caller, dbref enactor, int eval, int key,
     //
     if (!Controls(executor, victim))
     {
-        ap = NULL;
+        ap = nullptr;
         if (what != -1)
         {
             atr_get_info(victim, what, &aowner, &aflags);
@@ -2804,7 +2870,7 @@ void do_verb(dbref executor, dbref caller, dbref enactor, int eval, int key,
             what = -1;
         }
 
-        ap = NULL;
+        ap = nullptr;
         if (owhat != -1)
         {
             atr_get_info(victim, owhat, &aowner, &aflags);
@@ -2896,7 +2962,7 @@ static void ListReferences(dbref executor, UTF8 *reference_name)
     bool global_only = false;
     mux_string refstr(reference_name);
 
-    if (  NULL == reference_name
+    if (  nullptr == reference_name
        || '\0' == reference_name[0])
     {
         global_only = true;
@@ -2928,7 +2994,7 @@ static void ListReferences(dbref executor, UTF8 *reference_name)
 
     CHashTable* htab = &mudstate.reference_htab;
     for (  htab_entry = (struct reference_entry *) hash_firstentry(htab);
-           NULL != htab_entry;
+           nullptr != htab_entry;
            htab_entry = (struct reference_entry *) hash_nextentry(htab))
     {
         if (  (  global_only
@@ -3001,7 +3067,7 @@ void do_reference
     // References can only be set on objects the executor can examine.
     //
     dbref target = NOTHING;
-    if (  NULL != object_name
+    if (  nullptr != object_name
        && '\0' != object_name[0])
     {
         target = match_thing_quiet(executor, object_name);
@@ -3040,7 +3106,7 @@ void do_reference
 
     enum { Delete, Add, Update, NotFound, Redundant, OutOfMemory } eOperation;
 
-    if (NULL != result)
+    if (nullptr != result)
     {
         if (NOTHING == target)
         {
@@ -3079,9 +3145,9 @@ void do_reference
         // Release the existing reference.
         //
         MEMFREE(result->name);
-        result->name = NULL;
+        result->name = nullptr;
         MEMFREE(result);
-        result = NULL;
+        result = nullptr;
         hashdeleteLEN(tbuf, tbuf_len, &mudstate.reference_htab);
     }
 
@@ -3097,7 +3163,7 @@ void do_reference
             ; // Nothing;
         }
 
-        if (NULL != result)
+        if (nullptr != result)
         {
             result->target = target;
             result->owner = executor;
