@@ -1,8 +1,6 @@
 /*! \file stringutil.h
  * \brief string utilities.
  *
- * $Id: stringutil.h 5787 2016-02-14 03:55:45Z sdennis $
- *
  */
 
 #ifndef STRINGUTIL_H
@@ -12,7 +10,7 @@
 
 inline bool isEmpty(__in_opt const UTF8 *p)
 {
-    return ((NULL == p) || ('\0' == p[0]));
+    return ((nullptr == p) || ('\0' == p[0]));
 }
 
 extern const bool mux_isprint_ascii[256];
@@ -116,7 +114,7 @@ inline size_t TrimPartialSequence(size_t n, __in_ecount(n) const UTF8 *p)
 //
 inline bool mux_isprint(__in const unsigned char *p)
 {
-    unsigned char iState = CL_PRINT_START_STATE;
+    unsigned short iState = CL_PRINT_START_STATE;
     do
     {
         unsigned char ch = *p++;
@@ -268,7 +266,7 @@ inline bool mux_isobjectname(__in const unsigned char *p)
     {
         unsigned char ch = *p++;
         unsigned char iColumn = cl_objectname_itt[(unsigned char)ch];
-        unsigned char iOffset = cl_objectname_sot[iState];
+        unsigned short iOffset = cl_objectname_sot[iState];
         for (;;)
         {
             int y = cl_objectname_sbt[iOffset];
@@ -317,7 +315,7 @@ inline bool mux_isplayername(__in const unsigned char *p)
     {
         unsigned char ch = *p++;
         unsigned char iColumn = cl_playername_itt[(unsigned char)ch];
-        unsigned char iOffset = cl_playername_sot[iState];
+        unsigned short iOffset = cl_playername_sot[iState];
         for (;;)
         {
             int y = cl_playername_sbt[iOffset];
@@ -455,6 +453,202 @@ inline bool mux_is8859_2(__in const unsigned char *p)
     return ((iState - CL_8859_2_ACCEPTING_STATES_START) == 1) ? true : false;
 }
 
+// utf/cl_hangul.txt
+//
+inline bool mux_ishangul(__in const unsigned char *p)
+{
+    unsigned char iState = CL_HANGUL_START_STATE;
+    do
+    {
+        unsigned char ch = *p++;
+        unsigned char iColumn = cl_hangul_itt[(unsigned char)ch];
+        unsigned char iOffset = cl_hangul_sot[iState];
+        for (;;)
+        {
+            int y = cl_hangul_sbt[iOffset];
+            if (y < 128)
+            {
+                // RUN phrase.
+                //
+                if (iColumn < y)
+                {
+                    iState = cl_hangul_sbt[iOffset+1];
+                    break;
+                }
+                else
+                {
+                    iColumn = static_cast<unsigned char>(iColumn - y);
+                    iOffset += 2;
+                }
+            }
+            else
+            {
+                // COPY phrase.
+                //
+                y = 256-y;
+                if (iColumn < y)
+                {
+                    iState = cl_hangul_sbt[iOffset+iColumn+1];
+                    break;
+                }
+                else
+                {
+                    iColumn = static_cast<unsigned char>(iColumn - y);
+                    iOffset = static_cast<unsigned char>(iOffset + y + 1);
+                }
+            }
+        }
+    } while (iState < CL_HANGUL_ACCEPTING_STATES_START);
+    return ((iState - CL_HANGUL_ACCEPTING_STATES_START) == 1) ? true : false;
+}
+
+// utf/cl_hiragana.txt
+//
+inline bool mux_ishiragana(__in const unsigned char *p)
+{
+    unsigned char iState = CL_HIRAGANA_START_STATE;
+    do
+    {
+        unsigned char ch = *p++;
+        unsigned char iColumn = cl_hiragana_itt[(unsigned char)ch];
+        unsigned char iOffset = cl_hiragana_sot[iState];
+        for (;;)
+        {
+            int y = cl_hiragana_sbt[iOffset];
+            if (y < 128)
+            {
+                // RUN phrase.
+                //
+                if (iColumn < y)
+                {
+                    iState = cl_hiragana_sbt[iOffset+1];
+                    break;
+                }
+                else
+                {
+                    iColumn = static_cast<unsigned char>(iColumn - y);
+                    iOffset += 2;
+                }
+            }
+            else
+            {
+                // COPY phrase.
+                //
+                y = 256-y;
+                if (iColumn < y)
+                {
+                    iState = cl_hiragana_sbt[iOffset+iColumn+1];
+                    break;
+                }
+                else
+                {
+                    iColumn = static_cast<unsigned char>(iColumn - y);
+                    iOffset = static_cast<unsigned char>(iOffset + y + 1);
+                }
+            }
+        }
+    } while (iState < CL_HIRAGANA_ACCEPTING_STATES_START);
+    return ((iState - CL_HIRAGANA_ACCEPTING_STATES_START) == 1) ? true : false;
+}
+
+// utf/cl_kanji.txt
+//
+inline bool mux_iskanji(__in const unsigned char *p)
+{
+    unsigned char iState = CL_KANJI_START_STATE;
+    do
+    {
+        unsigned char ch = *p++;
+        unsigned char iColumn = cl_kanji_itt[(unsigned char)ch];
+        unsigned char iOffset = cl_kanji_sot[iState];
+        for (;;)
+        {
+            int y = cl_kanji_sbt[iOffset];
+            if (y < 128)
+            {
+                // RUN phrase.
+                //
+                if (iColumn < y)
+                {
+                    iState = cl_kanji_sbt[iOffset+1];
+                    break;
+                }
+                else
+                {
+                    iColumn = static_cast<unsigned char>(iColumn - y);
+                    iOffset += 2;
+                }
+            }
+            else
+            {
+                // COPY phrase.
+                //
+                y = 256-y;
+                if (iColumn < y)
+                {
+                    iState = cl_kanji_sbt[iOffset+iColumn+1];
+                    break;
+                }
+                else
+                {
+                    iColumn = static_cast<unsigned char>(iColumn - y);
+                    iOffset = static_cast<unsigned char>(iOffset + y + 1);
+                }
+            }
+        }
+    } while (iState < CL_KANJI_ACCEPTING_STATES_START);
+    return ((iState - CL_KANJI_ACCEPTING_STATES_START) == 1) ? true : false;
+}
+
+// utf/cl_katakana.txt
+//
+inline bool mux_iskatakana(__in const unsigned char *p)
+{
+    unsigned char iState = CL_KATAKANA_START_STATE;
+    do
+    {
+        unsigned char ch = *p++;
+        unsigned char iColumn = cl_katakana_itt[(unsigned char)ch];
+        unsigned char iOffset = cl_katakana_sot[iState];
+        for (;;)
+        {
+            int y = cl_katakana_sbt[iOffset];
+            if (y < 128)
+            {
+                // RUN phrase.
+                //
+                if (iColumn < y)
+                {
+                    iState = cl_katakana_sbt[iOffset+1];
+                    break;
+                }
+                else
+                {
+                    iColumn = static_cast<unsigned char>(iColumn - y);
+                    iOffset += 2;
+                }
+            }
+            else
+            {
+                // COPY phrase.
+                //
+                y = 256-y;
+                if (iColumn < y)
+                {
+                    iState = cl_katakana_sbt[iOffset+iColumn+1];
+                    break;
+                }
+                else
+                {
+                    iColumn = static_cast<unsigned char>(iColumn - y);
+                    iOffset = static_cast<unsigned char>(iOffset + y + 1);
+                }
+            }
+        }
+    } while (iState < CL_KATAKANA_ACCEPTING_STATES_START);
+    return ((iState - CL_KATAKANA_ACCEPTING_STATES_START) == 1) ? true : false;
+}
+
 // utf/tr_utf8_ascii.txt
 //
 const UTF8 *ConvertToAscii(__in const UTF8 *pString);
@@ -471,6 +665,10 @@ const UTF8 *ConvertToLatin1(__in const UTF8 *pString);
 //
 const UTF8 *ConvertToLatin2(__in const UTF8 *pString);
 
+// utf/tr_widths.txt
+//
+int ConsoleWidth(__in const UTF8 *pCodePoint);
+
 // utf/tr_tolower.txt
 //
 inline const string_desc *mux_tolower(__in const unsigned char *p, bool &bXor)
@@ -521,7 +719,7 @@ inline const string_desc *mux_tolower(__in const unsigned char *p, bool &bXor)
     if (TR_TOLOWER_DEFAULT == iState - TR_TOLOWER_ACCEPTING_STATES_START)
     {
         bXor = false;
-        return NULL;
+        return nullptr;
     }
     else
     {
@@ -580,7 +778,7 @@ inline const string_desc *mux_toupper(__in const unsigned char *p, bool &bXor)
     if (TR_TOUPPER_DEFAULT == iState - TR_TOUPPER_ACCEPTING_STATES_START)
     {
         bXor = false;
-        return NULL;
+        return nullptr;
     }
     else
     {
@@ -639,7 +837,7 @@ inline const string_desc *mux_totitle(__in const unsigned char *p, bool &bXor)
     if (TR_TOTITLE_DEFAULT == iState - TR_TOTITLE_ACCEPTING_STATES_START)
     {
         bXor = false;
-        return NULL;
+        return nullptr;
     }
     else
     {
@@ -698,7 +896,7 @@ inline const string_desc *mux_foldmatch(__in const unsigned char *p, bool &bXor)
     if (TR_FOLDMATCH_DEFAULT == iState - TR_FOLDMATCH_ACCEPTING_STATES_START)
     {
         bXor = false;
-        return NULL;
+        return nullptr;
     }
     else
     {
@@ -1694,11 +1892,11 @@ class mux_string
     // corresponds to strlen() in units of code points.
     //
     // If color is associated with the above code points, m_pcs will point
-    // to an array of ColorStates, otherwise, it is NULL.  When m_pcs is NULL,
-    // it is equivalent to every code point having CS_NORMAL color.  Each
-    // color state corresponds with a UTF-8 code point in m_autf[].  There is
-    // no guaranteed association between a position in m_autf[] and a position
-    // in m_pcs because UTF-8 code points are variable length.
+    // to an array of ColorStates, otherwise, it is nullptr.  When m_pcs is
+    // nullptr, it is equivalent to every code point having CS_NORMAL color.
+    // Each color state corresponds with a UTF-8 code point in m_autf[].
+    // There is no guaranteed association between a position in m_autf[] and
+    // a position in m_pcs because UTF-8 code points are variable length.
     //
     // Not all ColorStates in m_pcs may be used. m_ncs is between 0 and
     // LBUF_SIZE-1 inclusively and represents how many ColorStates are
@@ -1811,14 +2009,14 @@ public:
     bool search
     (
         const UTF8 *pPattern,
-        mux_cursor *iPos = NULL,
+        mux_cursor *iPos = nullptr,
         mux_cursor iStart = CursorMin,
         mux_cursor iEnd = CursorMax
     ) const;
     bool search
     (
         const mux_string &sPattern,
-        mux_cursor *iPos = NULL,
+        mux_cursor *iPos = nullptr,
         mux_cursor iStart = CursorMin,
         mux_cursor iEnd = CursorMax
     ) const;
@@ -1863,7 +2061,7 @@ public:
 
     static void operator delete(void *p)
     {
-        if (NULL != p)
+        if (nullptr != p)
         {
             free_string(p);
         }
@@ -2035,7 +2233,7 @@ public:
 
 inline bool isEmpty(const mux_string *p)
 {
-    return ((NULL == p) || (0 == p->length_byte()));
+    return ((nullptr == p) || (0 == p->length_byte()));
 }
 
 // String buffers are LBUF_SIZE, so maximum string length is LBUF_SIZE-1.
@@ -2055,7 +2253,7 @@ private:
 public:
 
     mux_words(const mux_string &sStr);
-    void export_WordColor(LBUF_OFFSET n, UTF8 *buff, UTF8 **bufc = NULL);
+    void export_WordColor(LBUF_OFFSET n, UTF8 *buff, UTF8 **bufc = nullptr);
     LBUF_OFFSET find_Words(const UTF8 *pDelim, bool bFavorEmptyList = false);
     void ignore_Word(LBUF_OFFSET n);
     mux_cursor wordBegin(LBUF_OFFSET n) const;
