@@ -1,8 +1,6 @@
 /*! \file strtod.cpp
  * \brief String to double conversion.
  *
- * $Id: strtod.cpp 5250 2011-02-20 19:23:37Z brazilofmux $
- *
  * \verbatim
  ****************************************************************
  *
@@ -445,14 +443,14 @@ static Bigint *Balloc(int k)
             rv = (Bigint*)MEMALLOC(len*sizeof(double));
         }
 #endif
-        if (NULL != rv)
+        if (nullptr != rv)
         {
             rv->k = k;
             rv->maxwds = x;
         }
     }
 
-    if (NULL != rv)
+    if (nullptr != rv)
     {
         rv->sign = rv->wds = 0;
     }
@@ -1384,8 +1382,8 @@ double mux_strtod(CONST UTF8 *s00, UTF8 **se)
     double aadj, aadj1, adj, rv, rv0;
     Long L;
     ULong y, z;
-    Bigint *bb = NULL, *bb1 = NULL, *bd = NULL, *bd0 = NULL, *bs = NULL;
-    Bigint *delta = NULL;
+    Bigint *bb = nullptr, *bb1 = nullptr, *bd = nullptr, *bd0 = nullptr, *bs = nullptr;
+    Bigint *delta = nullptr;
 #ifdef SET_INEXACT
     int inexact, oldinexact;
 #endif
@@ -2699,7 +2697,7 @@ UTF8 *mux_dtoa(double d, int mode, int ndigits, int *decpt, int *sign,
     int denorm;
     ULong x;
 #endif
-    Bigint *b = NULL, *b1 = NULL, *delta = NULL, *mlo = NULL, *mhi = NULL, *S = NULL;
+    Bigint *b = nullptr, *b1 = nullptr, *delta = nullptr, *mlo = nullptr, *mhi = nullptr, *S = nullptr;
     double d2, ds, eps;
     UTF8 *s, *s0;
 #ifdef Honor_FLT_ROUNDS
@@ -3126,7 +3124,7 @@ fast_failed:
                 }
 #endif
                 dval(d) += dval(d);
-                if (dval(d) > ds || dval(d) == ds && L & 1)
+                if (dval(d) > ds || (dval(d) == ds && L & 1))
                 {
 bump_up:
                     while (*--s == '9')
@@ -3343,11 +3341,11 @@ one_digit:
                 goto ret;
             }
 #endif
-            if (j < 0 || j == 0 && mode != 1
+            if (j < 0 || (j == 0 && mode != 1
 #ifndef ROUND_BIASED
                             && !(word1(d) & 1)
 #endif
-                    )
+                    ))
             {
                 if (!b->x[0] && b->wds <= 1)
                 {
@@ -3370,7 +3368,7 @@ one_digit:
                 {
                     b = lshift(b, 1);
                     j1 = cmp(b, S);
-                    if (  (j1 > 0 || j1 == 0 && dig & 1)
+                    if (  (j1 > 0 || (j1 == 0 && dig & 1))
                        && dig++ == '9')
                     {
                         goto round_9_up;
@@ -3450,7 +3448,7 @@ keep_dig:
 #endif
     b = lshift(b, 1);
     j = cmp(b, S);
-    if (j > 0 || j == 0 && dig & 1)
+    if (j > 0 || (j == 0 && dig & 1))
     {
 roundoff:
         while (*--s == '9')
