@@ -1,8 +1,6 @@
 /*! \file timer.cpp
  * \brief Mini-task scheduler for timed events.
  *
- * $Id: timer.cpp 4107 2009-01-18 17:24:43Z brazilofmux $
- *
  */
 
 #include "copyright.h"
@@ -10,7 +8,7 @@
 #include "config.h"
 #include "externs.h"
 
-#include <signal.h>
+#include <csignal>
 
 #include "command.h"
 #include "mathutil.h"
@@ -113,6 +111,35 @@ void dispatch_IdleCheck(void *pUnused, int iUnused)
     scheduler.DeferTask(mudstate.idle_counter, PRIORITY_SYSTEM, dispatch_IdleCheck, 0, 0);
 }
 
+void dispatch_KeepAlive(void *pUnused, int iUnused)
+{
+    UNUSED_PARAMETER(pUnused);
+    UNUSED_PARAMETER(iUnused);
+
+    DESC *d, *dnext;
+    DESC_SAFEITER_ALL(d, dnext)
+    {
+        if (  (d->flags & DS_CONNECTED)
+           && KeepAlive(d->player))
+        {
+            // Send a Telnet NOP code - creates traffic to keep NAT routers
+            // happy.
+            //
+            const UTF8 aNOP[2] = { NVT_IAC, NVT_NOP };
+            queue_write_LEN(d, aNOP, sizeof(aNOP));
+        }
+    }
+
+    // Schedule ourselves again.
+    //
+    CLinearTimeAbsolute ltaNow;
+    ltaNow.GetUTC();
+    CLinearTimeDelta ltd;
+    ltd.SetSeconds(mudconf.keepalive_interval);
+    mudstate.keepalive_counter = ltaNow + ltd;
+    scheduler.DeferTask(mudstate.keepalive_counter, PRIORITY_SYSTEM, dispatch_KeepAlive, 0, 0);
+}
+
 // Check Events Task routine.
 //
 void dispatch_CheckEvents(void *pUnused, int iUnused)
@@ -222,6 +249,12 @@ void init_timer(void)
     scheduler.DeferTask(mudstate.events_counter, PRIORITY_SYSTEM,
         dispatch_CheckEvents, 0, 0);
 
+    // Setup re-occuring KeepAlive task.
+    //
+    ltd.SetSeconds(mudconf.keepalive_interval);
+    mudstate.keepalive_counter = ltaNow + ltd;
+    scheduler.DeferTask(mudstate.keepalive_counter, PRIORITY_SYSTEM, dispatch_KeepAlive, 0, 0);
+
 #ifndef MEMORY_BASED
     // Setup re-occuring cache_tick task.
     //
@@ -264,7 +297,7 @@ void do_timewarp(dbref executor, dbref caller, dbref enactor, int eval, int key,
     //
     if ((key == 0) || (key & TWARP_QUEUE))
     {
-        do_queue(executor, caller, enactor, 0, QUEUE_WARP, arg, NULL, 0);
+        do_queue(executor, caller, enactor, 0, QUEUE_WARP, arg, nullptr, 0);
     }
 
     // Once these are adjusted, we need to Cancel and reschedule the task.
@@ -320,7 +353,7 @@ CTaskHeap::~CTaskHeap(void)
         {
             delete pTask;
         }
-        m_pHeap[m_nCurrent] = NULL;
+        m_pHeap[m_nCurrent] = nullptr;
     }
     if (m_pHeap)
     {
@@ -350,7 +383,7 @@ bool CTaskHeap::Grow(void)
     // Grow the heap.
     //
     int n = GrowFiftyPercent(m_nAllocated, INITIAL_TASKS, INT_MAX);
-    PTASK_RECORD *p = NULL;
+    PTASK_RECORD *p = nullptr;
     try
     {
         p = new PTASK_RECORD[n];
@@ -384,7 +417,7 @@ void CTaskHeap::Shrink(void)
         return;
     }
 
-    PTASK_RECORD *p = NULL;
+    PTASK_RECORD *p = nullptr;
     try
     {
         p = new PTASK_RECORD[n];
@@ -410,7 +443,7 @@ PTASK_RECORD CTaskHeap::PeekAtTopmost(void)
 {
     if (m_nCurrent <= 0)
     {
-        return NULL;
+        return nullptr;
     }
     return m_pHeap[0];
 }
@@ -429,7 +462,7 @@ void CTaskHeap::CancelTask(FTASK *fpTask, void *arg_voidptr, int arg_Integer)
            && p->arg_voidptr == arg_voidptr
            && p->arg_Integer == arg_Integer)
         {
-            p->fpTask = NULL;
+            p->fpTask = nullptr;
         }
     }
 }
@@ -524,7 +557,7 @@ void CScheduler::ReadyTasks(const CLinearTimeAbsolute& ltaNow)
         pTask = m_WhenHeap.RemoveTopmost(CompareWhen);
         if (pTask)
         {
-            if (  NULL == pTask->fpTask
+            if (  nullptr == pTask->fpTask
                || !m_PriorityHeap.Insert(pTask, ComparePriority))
             {
                 delete pTask;
@@ -666,7 +699,7 @@ void CTaskHeap::SiftUp(int child, SCHCMP *pfCompare)
 
 PTASK_RECORD CTaskHeap::Remove(int iNode, SCHCMP *pfCompare)
 {
-    if (iNode < 0 || m_nCurrent <= iNode) return NULL;
+    if (iNode < 0 || m_nCurrent <= iNode) return nullptr;
 
     PTASK_RECORD pTask = m_pHeap[iNode];
 
